
import mingc

# should raise an exception if return is non-zero:
mingc.Ming_init()

def Ming_setCubicThreshold(t):
    mingc.Ming_setCubicThreshold(t)

def Ming_setScale(scale):
    mingc.Ming_setScale(scale)

def Ming_getScale():
    return mingc.Ming_getScale()

def Ming_useSWFVersion(num):
    mingc.Ming_useSWFVersion(num)

def Ming_setSWFCompression( level ):
    return mingc.Ming_setSWFCompression( level )

def Ming_useConstants(flag):
   mingc.Ming_useConstants(flag)

def Ming_collectGarbage():
   mingc.Ming_collectGarbage()

class SWFBase:

    def __init__(self, o):
        self.this = o

    # reportedly useful for zope/zwiff:
    def set(self, name, val):
        setattr(self, name, val)


class SWFCXform(SWFBase):
	
    def __init__(rAdd=0, gAdd=0, bAdd=0, aAdd=0, rMult=1.0, gMult=1.0, bMult=1.0, aMult=1.0):
        self.this = mingc.newSWFCXform(rAdd, gAdd, bAdd, aAdd, rMult, gMult, bMult, aMult)

    def __del__(self):
        mingc.destroySWFCXform(self.this)

    def setColorAdd(self, rAdd, gAdd, bAdd, aAdd=0xff):
        mingc.SWFCXform_setColorAdd(self.this, rAdd, gAdd, bAdd, aAdd)

    def setColorMult(self, rMult, gMult, bMult, aMult):
        mingc.SWFCXform_setColorMult(self.this, rMult, gMult, bMult, aMult)

class SWFRect(SWFBase):

    def __init__(self, minX, maxX, minY, maxY):
        self.this = mingc.newSWFRect(minX, maxX, minY, maxY)

    def __del__(self):
        mingc.destroySWFRect(self.this)

    def getWidth(self):
        return mingc.SWFRect_getWidth(self.this)

    def getHeight(self):
        return mingc.SWFRect_getHeight(self.this)

class SWFShadow(SWFBase):
    def __init__(self, angle, distance, strength):
        self.this = mingc.newSWFShadow(angle, distance, strength)

    def __del__(self):
        mingc.destroySWFShadow(self.this)

class SWFBlur(SWFBase):
    def __init__(self, blurX, blurY, passes):
        self.this = mingc.newSWFBlur(blurX, blurY, passes)

    def __del__(self):
        mingc.destroySWFBlur(self.this)

class SWFFilterMatrix(SWFBase):
    def __init__(self, cols, rows, values):
        vals = floatArray(cols * rows)
        for i in range(0, cols*rows):
            vals[i] = values[i]
        self.this = mingc.newSWFFilterMatrix(cols, rows, vals)

    def __del__(self):
        mingc.destroySWFFilterMatrix(self.this)

SWFFILTER_TYPE_DROPSHADOW = mingc.SWFFILTER_TYPE_DROPSHADOW
SWFFILTER_TYPE_BLUR = mingc.SWFFILTER_TYPE_BLUR
SWFFILTER_TYPE_GLOW = mingc.SWFFILTER_TYPE_GLOW
SWFFILTER_TYPE_BEVEL = mingc.SWFFILTER_TYPE_BEVEL
SWFFILTER_TYPE_GRADIENTGLOW = mingc.SWFFILTER_TYPE_GRADIENTGLOW
SWFFILTER_TYPE_CONVOLUTION = mingc.SWFFILTER_TYPE_CONVOLUTION
SWFFILTER_TYPE_COLORMATRIX = mingc.SWFFILTER_TYPE_COLORMATRIX
SWFFILTER_TYPE_GRADIENTBEVEL = mingc.SWFFILTER_TYPE_GRADIENTBEVEL

SWFFILTER_MODE_INNER = mingc.SWFFILTER_MODE_INNER
SWFFILTER_MODE_KO = mingc.SWFFILTER_MODE_KO
SWFFILTER_MODE_COMPOSITE = mingc.SWFFILTER_MODE_COMPOSITE
SWFFILTER_MODE_ONTOP = mingc.SWFFILTER_MODE_ONTOP

SWFFILTER_FLAG_CLAMP = mingc.SWFFILTER_FLAG_CLAMP
SWFFILTER_FLAG_PRESERVE_ALPHA = mingc.SWFFILTER_FLAG_PRESERVE_ALPHA

class SWFFilter(SWFBase):
    def __del__(self):
        mingc.destroySWFFilter(self.this) 	

    def __init__(self, type, arg1=None, arg2=None, arg3=None, arg4=None, arg5=None):
        if type == SWFFILTER_TYPE_DROPSHADOW:
            #color, blur, shadow, flags
            if not isinstance(arg2, SWFBlur):
                raise AttributeError("3. parameter has to be SWFBlur")
            if not isinstance(arg3, SWFShadow):
                raise AttributeError("4. parameter has to be SWFShadow")
            self.this = mingc.newDropShadowFilter(arg1, arg2.this, arg3.this, arg4)
        elif type == SWFFILTER_TYPE_BLUR:
            #blur
            if not isinstance(arg1, SWFBlur):
                raise AttributeError("2. parameter has to be SWFBlur")
            self.this = mingc.newBlurFilter(arg1.this)
        elif type == SWFFILTER_TYPE_GLOW:
            #color, blur, strength, flags
            if not isinstance(arg2, SWFBlur):
                raise AttributeError("3. parameter has to be SWFBlur")
            self.this = mingc.newGlowFilter(arg1, arg2.this, arg3, arg4)
        elif type == SWFFILTER_TYPE_BEVEL:
            #shadowColor, highlightColor, blur, shadow, flags
            if not isinstance(arg3, SWFBlur):
                raise AttributeError("4. parameter has to be SWFBlur")
            if not isinstance(arg4, SWFShadow):
                raise AttributeError("5. parameter has to be SWFShadow")
            self.this = mingc.newBevelFilte(arg1, arg2, arg3.this, arg4.this, arg5)
        elif type == SWFFILTER_TYPE_GRADIENTGLOW:
            #gradient, blur, shadow, flags
            if not isinstance(arg1, SWFGradient):
                raise AttributeError("2. parameter has to be SWFGradient")
            if not isinstance(arg2, SWFBlur):
                raise AttributeError("3. parameter has to be SWFBlur")
            if not isinstance(arg3, SWFShadow):
                raise AttributeError("4. parameter has to be SWFShadow")
            self.this = mingc.newGradienGlowFilter(arg1.this, arg2.this, arg3.this, arg4)
        elif type == SWFFILTER_TYPE_COLORMATRIX:
            #colormatrix
            if not isinstance(arg1, SWFFilterMatrix):
                raise AttributeError("2. parameter has to be SWFFilterMatrix")
            self.this = mingc.newColorMatrixFilter(arg1.this)
        elif type == SWFFILTER_TYPE_CONVOLUTION:
            #colormatrix, divisor, bias, color, flags
            if not isinstance(arg1, SWFFilterMatrix):
                raise AttributeError("2. parameter has to be SWFFilterMatrix")
            self.this = mingc.newConvolutionFilter(arg1.this, arg2, arg3, arg4, arg5)
        elif type == SWFFILTER_TYPE_GRADIENTBEVEL:
            #gradient, blur, shadow, flags
            if not isinstance(arg1, SWFGradient):
                raise AttributeError("2. parameter has to be SWFGradient")
            if not isinstance(arg2, SWFBlur):
                raise AttributeError("3. parameter has to be SWFBlur")
            if not isinstance(arg3, SWFShadow):
                raise AttributeError("4. parameter has to be SWFShadow")
            self.this = mingc.newGradientBevelFilter(arg1.this, arg2.this, arg3.this, arg4)
        else:
            raise AttributeError("bad filter type to SWFFilter::new")

class SWFMatrix(SWFBase):
    
    def getScaleX(self):
        return mingc.SWFMatrix_getScaleX(self.this)

    def getScaleY(self):
        return mingc.SWFMatrix_getScaleY(self.this)

    def getRotate0(self):
        return mingc.SWFMatrix_getRotate0(self.this)

    def getRotate1(self):
        return mingc.SWFMatrix_getRotate1(self.this)

    def getTranslateX(self):
        return mingc.SWFMatrix_getTranslateX(self.this)

    def getTranslateY(self):
        return mingc.SWFMatrix_getTranslateY(self.this)

SWF_SHAPE3			= mingc.SWF_SHAPE3
SWF_SHAPE4			= mingc.SWF_SHAPE4
SWF_SHAPE_USESCALINGSTROKES	= mingc.SWF_SHAPE_USESCALINGSTROKES
SWF_SHAPE_USENONSCALINGSTROKES	= mingc.SWF_SHAPE_USENONSCALINGSTROKES

class SWFShape(SWFBase):

    def __init__(self, o=None):
        self.fills = []

        if o is None:
            self.this = mingc.newSWFShape()
        else:
            self.this = o

    def __del__(self):
        mingc.destroySWFShape(self.this)

    def setLine(self, width, r, g, b, a=0xff):
        mingc.SWFShape_setLine(self.this, width, r, g, b, a)

    def setLine2(self, width, r, g, b, a, flags, miter):
        mingc.SWFShape_setLine2(self.this, width, r, g, b, a, flags, miter)

    def setLine2Filled(self, width, fill, flags, miter):
        mingc.SWFShape_setLine2Filled(self.this, width, mingc.SWFFill_getFillStyle(fill.this), flags, miter)

    # I know there's probably a better way to do this..
    def addFill(self, arg1, arg2=0, arg3=None, arg4=0xff):
        if arg3 != None:
            return SWFFill(mingc.SWFShape_addSolidFill(self.this, arg1, arg2, arg3, arg4))
        if isinstance(arg1, SWFGradient):
            # XXX - have to keep reference to gradient so it's not disposed
            self.fills.append(arg1)
            return SWFFill(mingc.SWFShape_addGradientFill(self.this, arg1.this, arg2))

        if isinstance(arg1, SWFBitmap):
            # XXX - have to keep reference to bitmap so it's not disposed
            self.fills.append(arg1)
            return SWFFill(mingc.SWFShape_addBitmapFill(self.this, arg1.this, arg2))

        if isinstance(arg1, SWFJpegBitmap):
            self.fills.append(arg1)
            return SWFFill(mingc.SWFShape_addBitmapFill(self.this, arg1.this, arg2))

        else:
            raise AttributeError("bad argument to SWFShape::addFill")

    def setLeftFill(self, fill):
        mingc.SWFShape_setLeftFill(self.this, fill)

    def setRightFill(self, fill):
        mingc.SWFShape_setRightFill(self.this, fill)

    def movePenTo(self, x, y):
        mingc.SWFShape_movePenTo(self.this, x, y)

    def movePen(self, x, y):
        mingc.SWFShape_movePen(self.this, x, y)

    def drawLineTo(self, x, y):
        mingc.SWFShape_drawLineTo(self.this, x, y)

    def drawLine(self, dx, dy):
        mingc.SWFShape_drawLine(self.this, dx, dy)

    def drawArc(self, x, y, r, startAngle, endAngle):
        mingc.SWFShape_drawArc(self.this, x, y, r, startAngle, endAngle)

    def drawCircle(self, r):
        mingc.SWFShape_drawCircle(self.this, r)

    def drawCurveTo(self, bx, by, cx, cy, dx=None, dy=None):
        if(dx != None):
            mingc.SWFShape_drawCubicTo(self.this, bx, by, cx, cy, dx, dy)
        else:
            mingc.SWFShape_drawCurveTo(self.this, bx, by, cx, cy)

    def drawCurve(self, bx, by, cx, cy, dx=None, dy=None):
        if(dx != None):
            mingc.SWFShape_drawCubic(self.this, bx, by, cx, cy, dx, dy)
        else:
            mingc.SWFShape_drawCurve(self.this, bx, by, cx, cy)

    def drawCubicTo(self, bx, by, cx, cy, dx, dy):
        mingc.SWFShape_drawCubicTo(self.this, bx, by, cx, cy, dx, dy)

    def drawCubic(self, bx, by, cx, cy, dx, dy):
        mingc.SWFShape_drawCubic(self.this, bx, by, cx, cy, dx, dy)

    def drawGlyph(self, font, char, size=0):
        mingc.SWFShape_drawSizedGlyph(self.this, font.this, ord(char[0]), size)

    def drawCharacterBounds(self, char):
        mingc.SWFShape_drawCharacterBounds(self.this, char.this)

    def end(self):
        mingc.SWFShape_end(self.this)

    def useVersion(self, version):
        mingc.SWFShape_useVersion(self.this, version)

    def getVersion(self):
        return mingc.SWFShape_getVersion(self.this)

    def addSolidFill(self, r, g, b, a=0xff):
        return SWFFill(mingc.SWFShape_addSolidFill(self.this, r, g, b, a))

    def addGradientFill(self, gradient, flags):
        return SWFFill(mingc.SWFShape_addGradientFill(self.this, gradient.this, flags))

    def addBitmapFill(self, bitmap, flags):
        return SWFFill(mingc.SWFShape_addBitmapFill(self.this, bitmap.this, flags))

    def setRenderHintingFlags(self, flags):
        mingc.SWFShape_setRenderHintingFlags(self.this, flags)

    def getPenX(self):
        mingc.SWFShape_getPenX(self.this)

    def getPenY(self):
        mingc.SWFShape_getPenY(self.this)

    def hideLine(self):
        mingc.SWFShape_hideLine(self.this)
 
# addFill flags:
SWFFILL_SOLID		= mingc.SWFFILL_SOLID		
SWFFILL_GRADIENT	= mingc.SWFFILL_GRADIENT	
SWFFILL_LINEAR_GRADIENT = mingc.SWFFILL_LINEAR_GRADIENT 
SWFFILL_RADIAL_GRADIENT = mingc.SWFFILL_RADIAL_GRADIENT 
SWFFILL_BITMAP		= mingc.SWFFILL_BITMAP		
SWFFILL_TILED_BITMAP	= mingc.SWFFILL_TILED_BITMAP	
SWFFILL_CLIPPED_BITMAP	= mingc.SWFFILL_CLIPPED_BITMAP
#hinting flags
SWF_SHAPE_USESCALINGSTROKES    = mingc.SWF_SHAPE_USESCALINGSTROKES
SWF_SHAPE_USENONSCALINGSTROKES = mingc.SWF_SHAPE_USENONSCALINGSTROKES

class SWFFill(SWFBase):

    def __del__(self):
        mingc.destroySWFFill(self.this)

    def rotate(self, degrees):
        mingc.SWFFill_rotate(self.this, degrees)

    def rotateTo(self, degrees):
        mingc.SWFFill_rotateTo(self.this, degrees)

    def move(self, x, y):
        mingc.SWFFill_move(self.this, x, y)

    def moveTo(self, x, y):
        mingc.SWFFill_moveTo(self.this, x, y)

    def scale(self, xScale, yScale=None):
        if yScale is None:
            mingc.SWFFill_scaleXY(self.this, xScale, xScale)
        else:
            mingc.SWFFill_scaleXY(self.this, xScale, yScale)

    def scaleTo(self, xScale, yScale=None):
        if yScale is None:
            mingc.SWFFill_scaleXYTo(self.this, xScale, xScale)
        else:
            mingc.SWFFill_scaleXYTo(self.this, xScale, yScale)

    def scaleX(self, xScale):
        mingc.SWFFill_scaleX(self.this, xScale)

    def scaleXTo(self, xScale):
        mingc.SWFFill_scaleXTo(self.this, xScale)

    def scaleY(self, yScale):
        mingc.SWFFill_scaleY(self.this, yScale)

    def scaleYTo(self, yScale):
        mingc.SWFFill_scaleYTo(self.this, yScale)

    def skewX(self, x):
        mingc.SWFFill_skewX(self.this, x)

    def skewXTo(self, x):
        mingc.SWFFill_skewXTo(self.this, x)

    def skewY(self, y):
        mingc.SWFFill_skewY(self.this, y)

    def skewYTo(self, y):
        mingc.SWFFill_skewYTo(self.this, y)

    def setMatrix(self, a, b, c, d, x, y):
        mingc.SWFFill_setMatrix(self.this, a, b, c, d, x, y)

class SWFCharacter(SWFBase):

    def getWidth(self):
        mingc.SWFCharacter_getWidth(self.this)

    def getHeight(self):
        mingc.SWFCharacter_getHeight(self.this)

class SWFDisplayItem(SWFBase):

    def rotate(self, degrees):
        mingc.SWFDisplayItem_rotate(self.this, degrees)

    def rotateTo(self, degrees):
        mingc.SWFDisplayItem_rotateTo(self.this, degrees)

    def move(self, x, y):
        mingc.SWFDisplayItem_move(self.this, x, y)

    def moveTo(self, x, y):
        mingc.SWFDisplayItem_moveTo(self.this, x, y)

    def scale(self, xScale, yScale):
        mingc.SWFDisplayItem_scale(self.this, xScale, yScale)

    def scaleTo(self, xScale, yScale):
        mingc.SWFDisplayItem_scaleTo(self.this, xScale, yScale)

    def skewX(self, x):
        mingc.SWFDisplayItem_skewX(self.this, x)

    def skewXTo(self, x):
        mingc.SWFDisplayItem_skewXTo(self.this, x);

    def skewY(self, y):
        mingc.SWFDisplayItem_skewY(self.this, y)

    def skewYTo(self, y):
        mingc.SWFDisplayItem_skewYTo(self.this, y)

    def setName(self, name):
        mingc.SWFDisplayItem_setName(self.this, name)

    def setRatio(self, ratio):
        mingc.SWFDisplayItem_setRatio(self.this, ratio)

    def getDepth(self):
        return mingc.SWFDisplayItem_getDepth(self.this)

    def setDepth(self, depth):
        mingc.SWFDisplayItem_setDepth(self.this, depth)

    def addColor(self, r, g, b, a=0):
        mingc.SWFDisplayItem_setColorAdd(self.this, r, g, b, a)

    def multColor(self, r, g, b, a=1.0):
        mingc.SWFDisplayItem_setColorMult(self.this, r, g, b, a)

    def remove(self):
        mingc.SWFDisplayItem_remove(self.this)

    def setMatrix(self, a, b, c, d, x, y):
        mingc.SWFDisplayItem_setMatrix(self.this, a, b, c, d, x, y)

    def cacheAsBitmap(self, flag):
        mingc.SWFDisplayItem_cacheAsBitmap(self.this, flag)

    def setBlendMode(self, mode):
        mingc.SWFDisplayItem_setBlendMode(self.this, flag)

    def addAction(self, actionScript, flags):
        mingc.SWFDisplayItem_addAction(self.this, actionScript, flags)

    def setMaskLevel(self, level):
        mingc.SWFDisplayItem_setMaskLevel(self.this, level)

    def getPositionX(self):
        x = mingc.new_floatp()
        y = mingc.new_floatp()
        mingc.SWFDisplayItem_getPosition(self.this, x, y)
        ret = mingc.floatp_value(x)
        mingc.delete_floatp(x)
        mingc.delete_floatp(y)
        return ret

    def getPositionY(self):
        x = mingc.new_floatp()
        y = mingc.new_floatp()
        mingc.SWFDisplayItem_getPosition(self.this, x, y)
        ret = mingc.floatp_value(y)
        mingc.delete_floatp(x)
        mingc.delete_floatp(y)
        return ret

    def getRotation(self):
        rot = mingc.new_floatp()
        mingc.SWFDisplayItem_getRotation(self.this, rot)
        ret = mingc.floatp_value(rot)
        mingc.delete_floatp(rot)
        return ret

    def getScaleX(self):
        sx = mingc.new_floatp()
        sy = mingc.new_floatp()
        mingc.SWFDisplayItem_getScale(self.this, sx, sy)
        ret = mingc.floatp_value(sx)
        mingc.delete_floatp(sx)
        mingc.delete_floatp(sy)
        return ret

    def getScaleY(self):
        sx = mingc.new_floatp()
        sy = mingc.new_floatp()
        mingc.SWFDisplayItem_getScale(self.this, sx, sy)
        ret = mingc.floatp_value(sy)
        mingc.delete_floatp(sx)
        mingc.delete_floatp(sy)
        return ret

    def getSkewX(self):
        sx = mingc.new_floatp()
        sy = mingc.new_floatp()
        mingc.SWFDisplayItem_getSkew(self.this, sx, sy)
        ret = mingc.floatp_value(sx)
        mingc.delete_floatp(sx)
        mingc.delete_floatp(sy)
        return ret

    def getSkewY(self):
        sx = mingc.new_floatp()
        sy = mingc.new_floatp()
        mingc.SWFDisplayItem_getSkew(self.this, sx, sy)
        ret = mingc.floatp_value(sy)
        mingc.delete_floatp(sx)
        mingc.delete_floatp(sy)
        return ret

    def flush(self):
        mingc.SWFDisplayItem_flush(self.this)

    def endMask(self):
        mingc.SWFDisplayItem_endMask(self.this)

    def getMatrix(self):
        return SWFMatrix(mingc.SWFDisplayItem_getMatrix(self.this))

    def setCXform(self, cx):
        mingc.SWFDisplayItem_setCXform(self.this, cx.this);
         
    def addFilter(self, filter):
        mingc.SWFDisplayItem_addFilter(self.this, filter.this)

    def getCharacter(self):
        return SWFCharacter(mingc.SWFDisplayItem_getCharacter(self.this))

SWFACTION_ONLOAD      = mingc.SWFACTION_ONLOAD      
SWFACTION_ENTERFRAME  = mingc.SWFACTION_ENTERFRAME  
SWFACTION_UNLOAD      = mingc.SWFACTION_UNLOAD      
SWFACTION_MOUSEMOVE   = mingc.SWFACTION_MOUSEMOVE   
SWFACTION_MOUSEDOWN   = mingc.SWFACTION_MOUSEDOWN   
SWFACTION_MOUSEUP     = mingc.SWFACTION_MOUSEUP     
SWFACTION_KEYDOWN     = mingc.SWFACTION_KEYDOWN     
SWFACTION_KEYUP       = mingc.SWFACTION_KEYUP       
SWFACTION_DATA        = mingc.SWFACTION_DATA       

SWFBLEND_MODE_NULL	= mingc.SWFBLEND_MODE_NULL
SWFBLEND_MODE_NORMAL	= mingc.SWFBLEND_MODE_NORMAL
SWFBLEND_MODE_LAYER 	= mingc.SWFBLEND_MODE_LAYER
SWFBLEND_MODE_MULT	= mingc.SWFBLEND_MODE_MULT
SWFBLEND_MODE_SCREEN	= mingc.SWFBLEND_MODE_SCREEN
SWFBLEND_MODE_LIGHTEN	= mingc.SWFBLEND_MODE_LIGHTEN
SWFBLEND_MODE_DARKEN	= mingc.SWFBLEND_MODE_DARKEN
SWFBLEND_MODE_DIFF	= mingc.SWFBLEND_MODE_DIFF
SWFBLEND_MODE_ADD	= mingc.SWFBLEND_MODE_ADD
SWFBLEND_MODE_SUB	= mingc.SWFBLEND_MODE_SUB
SWFBLEND_MODE_INV	= mingc.SWFBLEND_MODE_INV
SWFBLEND_MODE_ALPHA	= mingc.SWFBLEND_MODE_ALPHA
SWFBLEND_MODE_ERASE	= mingc.SWFBLEND_MODE_ERASE
SWFBLEND_MODE_OVERLAY	= mingc.SWFBLEND_MODE_OVERLAY
SWFBLEND_MODE_HARDLIGHT = mingc.SWFBLEND_MODE_HARDLIGHT


class SWFMovie(SWFBase):

    def __init__(self):
        self.this = mingc.newSWFMovie()
        self.blocks = []

    def __del__(self):
        mingc.destroySWFMovie(self.this)

    def setRate(self, rate):
        mingc.SWFMovie_setRate(self.this, rate)

    def getRate(self):
        return mingc.SWFMovie_getRate(self.this)

    def setDimension(self, x, y):
        mingc.SWFMovie_setDimension(self.this, x, y)

    def setBackground(self, r, g, b):
        mingc.SWFMovie_setBackground(self.this, r, g, b)

    def setFrames(self, totalFrames):
        mingc.SWFMovie_setNumberOfFrames(self.this, totalFrames)

    # or:
    def setNumberOfFrames(self, totalFrames):
        mingc.SWFMovie_setNumberOfFrames(self.this, totalFrames)

    def protect(self, passwd=None):
        if passwd is None:
            mingc.SWFMovie_protect(self.this, None)
        else:
            mingc.SWFMovie_protect(self.this, passwd)


    def nextFrame(self):
        mingc.SWFMovie_nextFrame(self.this)

    def add(self, block):
        self.blocks.append(block)
        return SWFDisplayItem(mingc.SWFMovie_add(self.this, block.this))

    def remove(self, item):
        mingc.SWFMovie_remove(self.this, item.this)

    def replace(self, item, block):
        self.blocks.append(block)
        mingc.SWFMovie_replace(self.this, item.this, block.this)

    def streamMp3(self, mp3, skip=0.0):
        sound = SWFSoundStream(mp3)
        self.blocks.append(sound)
        mingc.SWFMovie_setSoundStreamAt(self.this, sound, skip)

    def setSoundStream(self, sound, skip=0.0):
        self.blocks.append(sound)
        mingc.SWFMovie_setSoundStreamAt(self.this, sound.this, skip);

    def output(self):
        return mingc.SWFMovie_simpleOutput(self.this)

    def save(self, filename):
        mingc.SWFMovie_save(self.this, filename)

    def saveToFile(self, file):
        mingc.SWFMovie_saveToFileNo(self.this, file.fileno())

    def labelFrame(self, label):
        mingc.SWFMovie_labelFrame(self.this, label)

    def namedAnchor(self, label):
        mingc.SWFMovie_namedAnchor(self.this, label)

    # deprecated:
    def simpleOutput(self):
        return mingc.SWFMovie_simpleOutput(self.this)

    def addExport(self, clipObj, libName):
        return mingc.SWFMovie_addExport(self.this, clipObj, libName)

    def writeExports(self):
        mingc.SWFMovie_writeExports(self.this)

    def assignSymbol(self, character, name):
        mingc.SWFMovie_assignSymbol(self.this, character.this, name)
	
    def setNetworkAccess(self, flag):
        mingc.SWFMovie_setNetworkAccess(self.this, flag)

    def addMetadata(self, xmldata):
        mingc.SWFMovie_addMetadata(self.this, xmldata)

    def setScriptLimits(self, maxRecursion, timeout):
        mingc.SWFMovie_setScriptLimits(self.this, maxRecursion, timeout)

    def setTabIndex(self, depth, index):
        mingc.SWFMovie_setTabIndex(self.this, depth, index)

    def defineScene(self, offset, name):
        mingc.SWFMovie_defineScene(self.this, offset, index)

    def addFont(self, font):
        return SWFFontCharacter(mingc.SWFMovie_addFont(self.this, font.this))

    def importFont(self, filename, name):
        return SWFFontCharacter(mingc.SWFMovie_importFont(self.this, filename, name))

    def startSound(self, sound):
        return SWFSoundInstance(mingc.SWFMovie_startSound(self.this, sound.this))

    def stopSound(self, sound):
        mingc.SWFMovie_stopSound(self.this, sound.this)

    def importCharacter(self):
        SWFCharacter(mingc.SWFMovie_importCharacter(self.this))


class SWFSprite(SWFBase):

    def __init__(self):
        self.this = mingc.newSWFMovieClip()
        self.blocks = []

    def __del__(self):
        mingc.destroySWFMovieClip(self.this)

    def setNumberOfFrames(self, frames):
        mingc.SWFMovieClip_setNumberOfFrames(self.this, frames)

    def add(self, block):
        self.blocks.append(block)
        return SWFDisplayItem(mingc.SWFMovieClip_add(self.this, block.this))

    def remove(self, item):
        mingc.SWFMovieClip_remove(self.this, item.this)

    def nextFrame(self):
        mingc.SWFMovieClip_nextFrame(self.this)

    def labelFrame(self, label):
        mingc.SWFMovieClip_labelFrame(self.this, label)

    def setScalingGrid(self, x, y, w, h):
        mingc.SWFMovieClip_setScalingGrid(self.this, x, y, w, h)

    def removeScalingGrid(self):
        mingc.SWFMovieClip_removeScalingGrid(self.this)

    def addInitAction(self, action):
        self.blocks.append(block)
        mingc.SWFMovieClip_addInitAction(self.this, action.this)

    def startSound(self, sound):
        return SWFSoundInstance(mingc.SWFMovieClip_startSound(self.this, sound.this))

    def stopSound(self, sound):
        mingc.SWFMovieClip_stopSound(self.this, sound.this)

    def setSoundStream(self, sound, rate, skip=0.0):
        self.blocks.append(sound)
        mingc.SWFMovieClip_setSoundStreamAt(self.this, sound.this, rate, skip);

# deprecated:
class SWFMovieClip(SWFSprite):
    pass


class SWFMorph(SWFBase):

    def __init__(self):
        self.this = mingc.newSWFMorphShape()

    def __del__(self):
        mingc.destroySWFMorph(self.this)

    def getShape1(self):
        # have to keep a reference so that it doesn't scope out
        self.shape1 = SWFShape(mingc.SWFMorph_getShape1(self.this))
        return self.shape1

    def getShape2(self):
        self.shape2 = SWFShape(mingc.SWFMorph_getShape2(self.this))
        return self.shape2

# deprecated:
class SWFMorphShape(SWFMorph):
    pass


class SWFBrowserFont(SWFBase):

    def __init__(self, name):
       self.this = mingc.newSWFBrowserFont(name)
       self.name = name

    def __del__(self):
       	mingc.destroySWFBrowserFont(self.this)		


class SWFFont(SWFBase):

    def __init__(self, name):
            self.this = mingc.newSWFFont_fromFile(name)
            self.name = name
        
    def __del__(self):
            mingc.destroySWFFont(self.this)

    def getAscent(self):
        return mingc.SWFFont_getAscent(self.this)

    def getDescent(self):
        return mingc.SWFFont_getDescent(self.this)

    def getLeading(self):
        return mingc.SWFFont_getLeading(self.this)

    def getUTF8StringWidth(self):
        return mingc.SWFFont_getUTF8StringWidth(self.this, string.encode("utf-8"))

    def getStringWidth(self, string):
        return mingc.SWFFont_getStringWidth(self.this, string)

    # or: (?)
    def getWidth(self, string):
        return mingc.SWFFont_getStringWidth(self.this, string)

    def getName(self):
        return mingc.SWFFont_getName(self.this)

    def getGlyphCount(self):
        return mingc.SWFFont_getGlyphCount(self.this)

class SWFFontCharacter(SWFBase):
     
     def addChars(self, string):
         mingc.SWFFontCharacter_addChars(self.this, string)

     def addUTF8Chars(self, string):
         mingc.SWFFontCharacter_addUTF8Chars(self.this, string)

     def addAllChars(self, string):
         mingc.SWFFontCharacter_addAllChars(self.this)

class SWFBitmap(SWFBase):

    def __init__(self, fname, alpha=None):
        ext = fname[-4:]

        if alpha is None:
            self.file = open(fname, "rb")
            self.this = mingc.newSWFBitmap_fromInput(mingc.newSWFInput_file(self.file))

        elif ext == '.jpg' or ext == '.JPG':
            self.file = open(fname, "rb")
            self.this = mingc.newSWFBitmap_fromInput(mingc.newSWFInput_file(self.file))

    def __del__(self):
        mingc.destroySWFBitmap(self.this)

    def getWidth(self):
        return mingc.SWFBitmap_getWidth(self.this)

    def getHeight(self):
        return mingc.SWFBitmap_getHeight(self.this)


class SWFFontCollection(SWFBase):

    def __init__(self, filename):
        self.this = mingc.newSWFFontCollection_fromFile(filename)

    def __del__(self):
        mingc.destroySWFFontCollection(self.this)

    def getFontCount(self):
        return mingc.SWFFontCollection_getFontCount(self.this)

    def getFont(self, index):
        return SWFFont(mingc.SWFFontCollection_getFont(self.this, index)) 


# deprecated:
class SWFDBLBitmap(SWFBitmap):

    def __init__(self, fname):
        self.this = mingc.newSWFDBLBitmap(open(fname, "rb"))


# deprecated:
class JpegBitmap(SWFBitmap):

    def __init__(self, fname, alpha=None):
        if alpha is None:
            self.this = mingc.newSWFJpegBitmap(open(fname, "rb"))
        else:
            self.this = mingc.newSWFJpegWithAlpha(open(fname, "rb"), open(alpha, "rb"))


class SWFText(SWFBase):

    def __init__(self, version=2):
        self.__fonts={} # keep reference
        if version == 2:
            self.this = mingc.newSWFText2()
        else:
            self.this = mingc.newSWFText()

    def __del__(self):
        mingc.destroySWFText(self.this)

    def setFont(self, font):
        self.__fonts[font.name] = font
        mingc.SWFText_setFont(self.this, font.this)

    def setHeight(self, height):
        mingc.SWFText_setHeight(self.this, height)

    def moveTo(self, x, y):
        mingc.SWFText_moveTo(self.this, x, y)

    def setColor(self, r, g, b, a=0xff):
        mingc.SWFText_setColor(self.this, r, g, b, a)

    def addString(self, s, advance=None):
        mingc.SWFText_addString(self.this, s, advance)

    def addUTF8String(self, s, advance=None):
        mingc.SWFText_addUTF8String(self.this, s.encode("utf-8"), advance)

    def setSpacing(self, spacing):
        mingc.SWFText_setSpacing(self.this, spacing)

    def getAscent(self):
        return mingc.SWFText_getAscent(self.this)

    def getDescent(self):
        return mingc.SWFText_getDescent(self.this)

    def getLeading(self):
        return mingc.SWFText_getLeading(self.this)

    def getWidth(self, string):
        return mingc.SWFText_getStringWidth(self.this, string)

    def getUTF8Width(self, s):
        return mingc.SWFText_getUTF8StringWidth(self.this, s.encode("utf-8")) 

    # deprecated:
    def setXY(self, x, y):
        mingc.SWFText_setXY(self.this, x, y)


class SWFText2(SWFText):

    def __init__(self):
        self.this = mingc.newSWFText2()


class SWFTextField(SWFBase):

    def __init__(self, flags=None):
        self.__fonts={} # keep reference
        self.this = mingc.newSWFTextField()

        if flags is not None:
            mingc.SWFTextField_setFlags(self.this, flags)

    def __del__(self):
        mingc.destroySWFTextField(self.this)

    def setFont(self, font):
        self.__fonts[font.name] = font
        mingc.SWFTextField_setFont(self.this, font.this)

    def setBounds(self, width, height):
        mingc.SWFTextField_setBounds(self.this, width, height)

    def setFlags(self, flags):
        mingc.SWFTextField_setFlags(self.this, flags)

    def setColor(self, r, g, b, a=0xff):
        mingc.SWFTextField_setColor(self.this, r, g, b, a)

    def setVariableName(self, name):
        mingc.SWFTextField_setVariableName(self.this, name)

    def addString(self, string):
        mingc.SWFTextField_addString(self.this, string)

    def addUTF8String(self, string):
        mingc.SWFTextField_addUTF8String(self.this, string.encode("utf-8"))

    def setHeight(self,  height):
        mingc.SWFTextField_setHeight(self.this,  height)

    def setLeftMargin(self, leftMargin):
        mingc.SWFTextField_setLeftMargin(self.this, leftMargin)

    def setRightMargin(self, rightMargin):
        mingc.SWFTextField_setRightMargin(self.this, rightMargin)

    def setIndentation(self, indentation):
        mingc.SWFTextField_setIndentation(self.this, indentation)

    def setLineSpacing(self, lineSpacing):
        mingc.SWFTextField_setLineSpacing(self.this, lineSpacing)

    def setAlignment(self, alignment):
        mingc.SWFTextField_setAlignment(self.this,  alignment)

    # or just:
    def align(self, alignment):
        mingc.SWFTextField_setAlignment(self.this,  alignment)

    def setLength(self, length):
        mingc.SWFTextField_setLength(self.this, length)

    def addChars(self, string):
        mingc.SWFTextField_addChars(self.this, string)

    def setPadding(self, pad):
        mingc.SWFTextField_setPadding(self.this, pad)

    def setFieldHeight(self, height):
        mingc.SWFTextField_setFieldHeight(self.this, height)

# textfield alignment flags:
SWFTEXTFIELD_ALIGN_LEFT    = mingc.SWFTEXTFIELD_ALIGN_LEFT
SWFTEXTFIELD_ALIGN_RIGHT   = mingc.SWFTEXTFIELD_ALIGN_RIGHT
SWFTEXTFIELD_ALIGN_CENTER  = mingc.SWFTEXTFIELD_ALIGN_CENTER
SWFTEXTFIELD_ALIGN_JUSTIFY = mingc.SWFTEXTFIELD_ALIGN_JUSTIFY

# other flags:

SWFTEXTFIELD_ONMASK    = mingc.SWFTEXTFIELD_ONMASK    
SWFTEXTFIELD_OFFMASK   = mingc.SWFTEXTFIELD_OFFMASK   
SWFTEXTFIELD_HASFONT   = mingc.SWFTEXTFIELD_HASFONT   
SWFTEXTFIELD_HASLENGTH = mingc.SWFTEXTFIELD_HASLENGTH 
SWFTEXTFIELD_HASCOLOR  = mingc.SWFTEXTFIELD_HASCOLOR  
SWFTEXTFIELD_NOEDIT    = mingc.SWFTEXTFIELD_NOEDIT    
SWFTEXTFIELD_PASSWORD  = mingc.SWFTEXTFIELD_PASSWORD  
SWFTEXTFIELD_MULTILINE = mingc.SWFTEXTFIELD_MULTILINE 
SWFTEXTFIELD_WORDWRAP  = mingc.SWFTEXTFIELD_WORDWRAP  
SWFTEXTFIELD_HASTEXT   = mingc.SWFTEXTFIELD_HASTEXT   
SWFTEXTFIELD_USEFONT   = mingc.SWFTEXTFIELD_USEFONT   
SWFTEXTFIELD_HTML      = mingc.SWFTEXTFIELD_HTML      
SWFTEXTFIELD_DRAWBOX   = mingc.SWFTEXTFIELD_DRAWBOX   
SWFTEXTFIELD_NOSELECT  = mingc.SWFTEXTFIELD_NOSELECT  
SWFTEXTFIELD_HASLAYOUT = mingc.SWFTEXTFIELD_HASLAYOUT 
SWFTEXTFIELD_AUTOSIZE  = mingc.SWFTEXTFIELD_AUTOSIZE

class SWFSoundStream(SWFBase):
	
    def __init__(self, fname):
        self.file = open(fname, "rb")
        self.this = mingc.newSWFSoundStream(self.file)

    def getDuration(self):
        return mingc.SWFSoundStream_getDuration(self.this)

    def setInitialMp3Delay(self, delay):
        mingc.SWFSoundStream_setInitialMp3Delay(self.this, delay)

class SWFSound(SWFBase):

    def __init__(self, arg, flags=0):
        self.arg = arg;
        if isinstance(arg, SWFSoundStream):
            self.this = mingc.newSWFSound_fromSoundStream(arg)
        else:
            self.file = open(arg, "rb")
            self.this = mingc.newSWFSound(self.file, flags)

    def setInitialMp3Delay(self, delay):
        mingc.SWFSound_setInitialMp3Delay(self.this, delay)

    # display list destroys this..

SWF_SOUND_COMPRESSION       = mingc.SWF_SOUND_COMPRESSION       
SWF_SOUND_NOT_COMPRESSED    = mingc.SWF_SOUND_NOT_COMPRESSED    
SWF_SOUND_ADPCM_COMPRESSED  = mingc.SWF_SOUND_ADPCM_COMPRESSED  
SWF_SOUND_MP3_COMPRESSED    = mingc.SWF_SOUND_MP3_COMPRESSED    
SWF_SOUND_NOT_COMPRESSED_LE = mingc.SWF_SOUND_NOT_COMPRESSED_LE 
SWF_SOUND_NELLY_COMPRESSED  = mingc.SWF_SOUND_NELLY_COMPRESSED  
SWF_SOUND_RATE              = mingc.SWF_SOUND_RATE              
SWF_SOUND_5KHZ              = mingc.SWF_SOUND_5KHZ              
SWF_SOUND_11KHZ             = mingc.SWF_SOUND_11KHZ             
SWF_SOUND_22KHZ             = mingc.SWF_SOUND_22KHZ             
SWF_SOUND_44KHZ             = mingc.SWF_SOUND_44KHZ             
SWF_SOUND_BITS              = mingc.SWF_SOUND_BITS              
SWF_SOUND_8BITS             = mingc.SWF_SOUND_8BITS             
SWF_SOUND_16BITS            = mingc.SWF_SOUND_16BITS            
SWF_SOUND_CHANNELS          = mingc.SWF_SOUND_CHANNELS          
SWF_SOUND_MONO              = mingc.SWF_SOUND_MONO              
SWF_SOUND_STEREO            = mingc.SWF_SOUND_STEREO            

class SWFSoundInstance(SWFBase):

    def setNoMultiple(self):
        mingc.SWFSoundInstance_setNoMultiple(self.this)

    def setLoopInPoint(self, point):
        mingc.SWFSoundInstance_setLoopInPoint(self.this, point)

    def setLoopOutPoint(self, point):
        mingc.SWFSoundInstance_setLoopOutPoint(self.this, point)

    def setLoopCount(self, count):
        mingc.SWFSoundInstance_setLoopCount(self.this, count)

    def addEnvelope(self, mark44, left, right):
        mingc.SWFSoundInstance_addEnvelope(self.this, mark44, left, right)

class SWFAction(SWFBase):

    def __init__(self, script):
        self.this = mingc.newSWFAction(script)

    def compile(swfVersion):
        return mingc.SWFAction_compile(self.this, swfVersion, NULL)

class SWFInitAction(SWFBase):

   def __init__(self, action):
       self.this = mingc.newSWFInitAction(action.this)

    # assigned object will destroy this..

SWF_GRADIENT_PAD	= mingc.SWF_GRADIENT_PAD
SWF_GRADIENT_REFLECT	= mingc.SWF_GRADIENT_REFLECT
SWF_GRADIENT_REPEAT	= mingc.SWF_GRADIENT_REPEAT
SWF_GRADIENT_NORMAL	= mingc.SWF_GRADIENT_NORMAL
SWF_GRADIENT_LINEAR	= mingc.SWF_GRADIENT_LINEAR

class SWFGradient(SWFBase):

    def __init__(self):
        self.this = mingc.newSWFGradient()

    def __del__(self):
        mingc.destroySWFGradient(self.this)

    def addEntry(self, ratio, r, g, b, a=0xff):
        mingc.SWFGradient_addEntry(self.this, ratio, r, g, b, a)

    def setSpreadMode(self, mode):
        mingc.SWFGradient_setSpreadMode(self.this, mode)

    def setInterpolationMode(self, mode):
        mingc.SWFGradient_setInterpolationMode(self.this, mode)

    def SWFGradient_setFocalPoint(self, fp):
        mingc.SWFGradient_setFocalPoint(self.this, fp)

class SWFButton(SWFBase):

    def __init__(self):
        self.this = mingc.newSWFButton()
        self.shapes = []

    def __del__(self):
        mingc.destroySWFButton(self.this)

    def setUp(self, character):
        self.addShape(character, SWFBUTTON_UP)

    def setDown(self, character):
        self.addShape(character, SWFBUTTON_DOWN)

    def setOver(self, character):
        self.addShape(character, SWFBUTTON_OVER)

    def setHit(self, character):
        self.addShape(character, SWFBUTTON_HIT)

    def addShape(self, character, flags):
        self.shapes.append(character)
        mingc.SWFButton_addCharacter(self.this, character, flags)

    def addAction(self, action, flags):
        mingc.SWFButton_addAction(self.this, action.this, flags)

    def addCharacter(self, character, flags):
        self.shapes.append(character)
        return SWFButtonRecord(mingc.SWFButton_addCharacter(self.this, character, flags))

    def addSound(self, sound, flags):
        return SWFSoundInstance(mingc.SWFButton_addSound(self.this, sound.this, flags))

    def setMenu(self, flag):
        mingc.SWFButton_setMenu(self.this, flag)

    def setScalingGrid(self, x, y, w, h):
        mingc.SWFButton_setScalingGrid(self.this, x, y, w, h)

    def removeScalingGrid(self):
        mingc.SWFButton_removeScalingGrid(self.this)

class SWFButtonRecord(SWFBase):

    def setDepth(self, depth):
        mingc.SWFButtonRecord_setDepth(self.this, depth)

    def setBlendMode(self, mode):
        mingc.SWFButtonRecord_setBlendMode(self.this, mode)

    def move(self, x, y):
        mingc.SWFButtonRecord_move(self.this, x, y)

    def moveTo(self, x, y):
        mingc.SWFButtonRecord_moveTo(self.this, x, y)

    def rotate(self, deg):
        mingc.SWFButtonRecord_rotate(self.this, deg)

    def rotateTo(self, deg):
        mingc.SWFButtonRecord_rotateTo(self.this, deg)

    def scale(self, sx, sy):
        mingc.SWFButtonRecord_scale(self.this, sx, sy)

    def scaleTo(self, sx, sy):
        mingc.SWFButtonRecord_scaleTo(self.this, sx, sy)

    def skewX(self, sx):
        mingc.SWFButtonRecord_skewX(self.this, sx)

    def skewXTo(self, sx):
        mingc.SWFButtonRecord_skewXTo(self.this, sx)

    def skewY(self, sy):
        mingc.SWFButtonRecord_skewY(self.this, sy)

    def skewYTo(self, sy):
        mingc.SWFButtonRecord_skewXTo(self.this, sy)

    def addFilter(self, filter):
        mingc.SWFButtonRecord_addFilter(self.this, filter.this)

SWFVIDEOSTREAM_MODE_AUTO = mingc.SWFVIDEOSTREAM_MODE_AUTO
SWFVIDEOSTREAM_MODE_MANUAL = mingc.SWFVIDEOSTREAM_MODE_MANUAL

class SWFVideoStream(SWFBase):
    def __init__(self, filename=None):
        if filename is None:
                self.file = 0;
                self.this = mingc.newSWFVideoStream()
        else:
                self.file = open(filename, "rb");
                self.this = mingc.newSWFVideoStream_fromFile(self.file)
    def setDimension(self, w, h):
        return mingc.SWFVideoStream_setDimension(self.this, w, h)
    def getNumFrames(self):
        return mingc.SWFVideoStream_getNumFrames(self.this)
    def hasAudio(self):
        return mingc.SWFVideoStream_hasAudio(self.this)
    def setFrameMode(self, mode):
        return mingc.SWFVideoStream_setFrameMode(self.this, mode)
    def nextFrame(self):
        return mingc.SWFVideoStream_nextFrame(self.this)
    def seek(self, frame, whence):
        return mingc.SWFVideoStream_seek(self.this, frame, whence)
    def __del__(self):
        mingc.destroySWFVideoStream(self.this)

def SWFBUTTON_KEYPRESS(c):
    return mingc.swfButton_keypress(c)

# addShape flags:
SWFBUTTON_UP             = mingc.SWFBUTTON_UP
SWFBUTTON_HIT            = mingc.SWFBUTTON_HIT
SWFBUTTON_DOWN           = mingc.SWFBUTTON_DOWN
SWFBUTTON_OVER           = mingc.SWFBUTTON_OVER

# addAction flags:
SWFBUTTON_MOUSEUPOUTSIDE = mingc.SWFBUTTON_MOUSEUPOUTSIDE
SWFBUTTON_DRAGOVER       = mingc.SWFBUTTON_DRAGOVER
SWFBUTTON_DRAGOUT        = mingc.SWFBUTTON_DRAGOUT
SWFBUTTON_MOUSEUP        = mingc.SWFBUTTON_MOUSEUP
SWFBUTTON_MOUSEDOWN      = mingc.SWFBUTTON_MOUSEDOWN
SWFBUTTON_MOUSEOUT       = mingc.SWFBUTTON_MOUSEOUT
SWFBUTTON_MOUSEOVER      = mingc.SWFBUTTON_MOUSEOVER

class SWFPrebuiltClip(SWFBase):
    def __init__(self, filename):
        self.this = mingc.newSWFPrebuiltClip_fromFile(filename)
    def __del__(self):
        mingc.destroySWFPrebuiltClip(self.this)

class SWFBinaryData(SWFBase):
    def __init__(self, string, len):
        self.this = mingc.newSWFBinaryData(string, len)
    def __del__(self):
        mingc.destroySWFBinaryData(self.this)



# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.0
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _mingc
else:
    import _mingc

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)



def new_intp():
    return _mingc.new_intp()

def copy_intp(value):
    return _mingc.copy_intp(value)

def delete_intp(obj):
    return _mingc.delete_intp(obj)

def intp_assign(obj, value):
    return _mingc.intp_assign(obj, value)

def intp_value(obj):
    return _mingc.intp_value(obj)

def new_floatp():
    return _mingc.new_floatp()

def copy_floatp(value):
    return _mingc.copy_floatp(value)

def delete_floatp(obj):
    return _mingc.delete_floatp(obj)

def floatp_assign(obj, value):
    return _mingc.floatp_assign(obj, value)

def floatp_value(obj):
    return _mingc.floatp_value(obj)
class floatArray(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, nelements):
        _mingc.floatArray_swiginit(self, _mingc.new_floatArray(nelements))
    __swig_destroy__ = _mingc.delete_floatArray

    def __getitem__(self, index):
        return _mingc.floatArray___getitem__(self, index)

    def __setitem__(self, index, value):
        return _mingc.floatArray___setitem__(self, index, value)

    def cast(self):
        return _mingc.floatArray_cast(self)

    @staticmethod
    def frompointer(t):
        return _mingc.floatArray_frompointer(t)

# Register floatArray in _mingc:
_mingc.floatArray_swigregister(floatArray)

def Ming_init():
    return _mingc.Ming_init()

def Ming_cleanup():
    return _mingc.Ming_cleanup()

def Ming_collectGarbage():
    return _mingc.Ming_collectGarbage()

def Ming_useConstants(flag):
    return _mingc.Ming_useConstants(flag)

def Ming_setCubicThreshold(num):
    return _mingc.Ming_setCubicThreshold(num)

def Ming_setScale(scale):
    return _mingc.Ming_setScale(scale)

def Ming_getScale():
    return _mingc.Ming_getScale()

def Ming_useSWFVersion(version):
    return _mingc.Ming_useSWFVersion(version)

def Ming_setSWFCompression(level):
    return _mingc.Ming_setSWFCompression(level)

def SWFMatrix_getScaleX(m):
    return _mingc.SWFMatrix_getScaleX(m)

def SWFMatrix_getRotate0(m):
    return _mingc.SWFMatrix_getRotate0(m)

def SWFMatrix_getRotate1(m):
    return _mingc.SWFMatrix_getRotate1(m)

def SWFMatrix_getScaleY(m):
    return _mingc.SWFMatrix_getScaleY(m)

def SWFMatrix_getTranslateX(m):
    return _mingc.SWFMatrix_getTranslateX(m)

def SWFMatrix_getTranslateY(m):
    return _mingc.SWFMatrix_getTranslateY(m)

def newSWFInput_file(f):
    return _mingc.newSWFInput_file(f)

def newSWFInput_stream(f):
    return _mingc.newSWFInput_stream(f)

def newSWFInput_buffer(buffer, length):
    return _mingc.newSWFInput_buffer(buffer, length)

def newSWFInput_allocedBuffer(buffer, length):
    return _mingc.newSWFInput_allocedBuffer(buffer, length)

def destroySWFInput(input):
    return _mingc.destroySWFInput(input)

def SWFInput_length(input):
    return _mingc.SWFInput_length(input)

def SWFInput_rewind(input):
    return _mingc.SWFInput_rewind(input)

def SWFInput_tell(input):
    return _mingc.SWFInput_tell(input)

def SWFInput_seek(input, offset, whence):
    return _mingc.SWFInput_seek(input, offset, whence)

def SWFInput_eof(input):
    return _mingc.SWFInput_eof(input)

def SWFCharacter_getWidth(character):
    return _mingc.SWFCharacter_getWidth(character)

def SWFCharacter_getHeight(character):
    return _mingc.SWFCharacter_getHeight(character)

def newSWFBitmap_fromInput(input):
    return _mingc.newSWFBitmap_fromInput(input)

def destroySWFBitmap(bitmap):
    return _mingc.destroySWFBitmap(bitmap)

def SWFBitmap_getWidth(b):
    return _mingc.SWFBitmap_getWidth(b)

def SWFBitmap_getHeight(b):
    return _mingc.SWFBitmap_getHeight(b)

def newSWFDBLBitmap(f):
    return _mingc.newSWFDBLBitmap(f)

def newSWFDBLBitmap_fromInput(input):
    return _mingc.newSWFDBLBitmap_fromInput(input)

def newSWFJpegBitmap(f):
    return _mingc.newSWFJpegBitmap(f)

def newSWFJpegBitmap_fromInput(input):
    return _mingc.newSWFJpegBitmap_fromInput(input)

def newSWFJpegWithAlpha(f, alpha):
    return _mingc.newSWFJpegWithAlpha(f, alpha)

def newSWFJpegWithAlpha_fromInput(input, alpha):
    return _mingc.newSWFJpegWithAlpha_fromInput(input, alpha)
SWF_GRADIENT_PAD = _mingc.SWF_GRADIENT_PAD
SWF_GRADIENT_REFLECT = _mingc.SWF_GRADIENT_REFLECT
SWF_GRADIENT_REPEAT = _mingc.SWF_GRADIENT_REPEAT
SWF_GRADIENT_NORMAL = _mingc.SWF_GRADIENT_NORMAL
SWF_GRADIENT_LINEAR = _mingc.SWF_GRADIENT_LINEAR

def newSWFGradient():
    return _mingc.newSWFGradient()

def destroySWFGradient(gradient):
    return _mingc.destroySWFGradient(gradient)

def SWFGradient_addEntry(gradient, ratio, r, g, b, a):
    return _mingc.SWFGradient_addEntry(gradient, ratio, r, g, b, a)

def SWFGradient_setSpreadMode(gradient, mode):
    return _mingc.SWFGradient_setSpreadMode(gradient, mode)

def SWFGradient_setInterpolationMode(gradient, mode):
    return _mingc.SWFGradient_setInterpolationMode(gradient, mode)

def SWFGradient_setFocalPoint(gradient, focalPoint):
    return _mingc.SWFGradient_setFocalPoint(gradient, focalPoint)
SWFFILL_SOLID = _mingc.SWFFILL_SOLID
SWFFILL_GRADIENT = _mingc.SWFFILL_GRADIENT
SWFFILL_LINEAR_GRADIENT = _mingc.SWFFILL_LINEAR_GRADIENT
SWFFILL_RADIAL_GRADIENT = _mingc.SWFFILL_RADIAL_GRADIENT
SWFFILL_BITMAP = _mingc.SWFFILL_BITMAP
SWFFILL_TILED_BITMAP = _mingc.SWFFILL_TILED_BITMAP
SWFFILL_CLIPPED_BITMAP = _mingc.SWFFILL_CLIPPED_BITMAP

def newSWFSolidFillStyle(r, g, b, a):
    return _mingc.newSWFSolidFillStyle(r, g, b, a)

def newSWFGradientFillStyle(gradient, radial):
    return _mingc.newSWFGradientFillStyle(gradient, radial)

def newSWFBitmapFillStyle(bitmap, flags):
    return _mingc.newSWFBitmapFillStyle(bitmap, flags)

def SWFFillStyle_getMatrix(fill):
    return _mingc.SWFFillStyle_getMatrix(fill)

def newSWFLineStyle(width, r, g, b, a):
    return _mingc.newSWFLineStyle(width, r, g, b, a)
SWF_LINESTYLE_CAP_ROUND = _mingc.SWF_LINESTYLE_CAP_ROUND
SWF_LINESTYLE_CAP_NONE = _mingc.SWF_LINESTYLE_CAP_NONE
SWF_LINESTYLE_CAP_SQUARE = _mingc.SWF_LINESTYLE_CAP_SQUARE
SWF_LINESTYLE_JOIN_ROUND = _mingc.SWF_LINESTYLE_JOIN_ROUND
SWF_LINESTYLE_JOIN_BEVEL = _mingc.SWF_LINESTYLE_JOIN_BEVEL
SWF_LINESTYLE_JOIN_MITER = _mingc.SWF_LINESTYLE_JOIN_MITER
SWF_LINESTYLE_FLAG_NOHSCALE = _mingc.SWF_LINESTYLE_FLAG_NOHSCALE
SWF_LINESTYLE_FLAG_NOVSCALE = _mingc.SWF_LINESTYLE_FLAG_NOVSCALE
SWF_LINESTYLE_FLAG_HINTING = _mingc.SWF_LINESTYLE_FLAG_HINTING
SWF_LINESTYLE_FLAG_NOCLOSE = _mingc.SWF_LINESTYLE_FLAG_NOCLOSE
SWF_LINESTYLE_FLAG_ENDCAP_ROUND = _mingc.SWF_LINESTYLE_FLAG_ENDCAP_ROUND
SWF_LINESTYLE_FLAG_ENDCAP_NONE = _mingc.SWF_LINESTYLE_FLAG_ENDCAP_NONE
SWF_LINESTYLE_FLAG_ENDCAP_SQUARE = _mingc.SWF_LINESTYLE_FLAG_ENDCAP_SQUARE

def newSWFLineStyle2(width, r, g, b, a, flags, miterLimit):
    return _mingc.newSWFLineStyle2(width, r, g, b, a, flags, miterLimit)

def newSWFLineStyle2_filled(width, fill, flags, miterLimit):
    return _mingc.newSWFLineStyle2_filled(width, fill, flags, miterLimit)
SWF_SHAPE3 = _mingc.SWF_SHAPE3
SWF_SHAPE4 = _mingc.SWF_SHAPE4
SWF_SHAPE_USESCALINGSTROKES = _mingc.SWF_SHAPE_USESCALINGSTROKES
SWF_SHAPE_USENONSCALINGSTROKES = _mingc.SWF_SHAPE_USENONSCALINGSTROKES

def newSWFShape():
    return _mingc.newSWFShape()

def newSWFShapeFromBitmap(bitmap, flag):
    return _mingc.newSWFShapeFromBitmap(bitmap, flag)

def destroySWFShape(shape):
    return _mingc.destroySWFShape(shape)

def SWFShape_end(shape):
    return _mingc.SWFShape_end(shape)

def SWFShape_useVersion(shape, version):
    return _mingc.SWFShape_useVersion(shape, version)

def SWFShape_getVersion(shape):
    return _mingc.SWFShape_getVersion(shape)

def SWFShape_setRenderHintingFlags(shape, flags):
    return _mingc.SWFShape_setRenderHintingFlags(shape, flags)

def SWFShape_movePenTo(shape, x, y):
    return _mingc.SWFShape_movePenTo(shape, x, y)

def SWFShape_movePen(shape, x, y):
    return _mingc.SWFShape_movePen(shape, x, y)

def SWFShape_getPenX(shape):
    return _mingc.SWFShape_getPenX(shape)

def SWFShape_getPenY(shape):
    return _mingc.SWFShape_getPenY(shape)

def SWFShape_getPen(shape, penX, penY):
    return _mingc.SWFShape_getPen(shape, penX, penY)

def SWFShape_drawLineTo(shape, x, y):
    return _mingc.SWFShape_drawLineTo(shape, x, y)

def SWFShape_drawLine(shape, dx, dy):
    return _mingc.SWFShape_drawLine(shape, dx, dy)

def SWFShape_drawCurveTo(shape, controlx, controly, anchorx, anchory):
    return _mingc.SWFShape_drawCurveTo(shape, controlx, controly, anchorx, anchory)

def SWFShape_drawCurve(shape, controldx, controldy, anchordx, anchordy):
    return _mingc.SWFShape_drawCurve(shape, controldx, controldy, anchordx, anchordy)

def SWFShape_hideLine(shape):
    return _mingc.SWFShape_hideLine(shape)

def SWFShape_addSolidFillStyle(shape, r, g, b, a):
    return _mingc.SWFShape_addSolidFillStyle(shape, r, g, b, a)

def SWFShape_addGradientFillStyle(shape, gradient, flags):
    return _mingc.SWFShape_addGradientFillStyle(shape, gradient, flags)

def SWFShape_addBitmapFillStyle(shape, bitmap, flags):
    return _mingc.SWFShape_addBitmapFillStyle(shape, bitmap, flags)

def SWFShape_setLeftFillStyle(shape, fill):
    return _mingc.SWFShape_setLeftFillStyle(shape, fill)

def SWFShape_setRightFillStyle(shape, fill):
    return _mingc.SWFShape_setRightFillStyle(shape, fill)

def newSWFMorphShape():
    return _mingc.newSWFMorphShape()

def destroySWFMorph(morph):
    return _mingc.destroySWFMorph(morph)

def SWFMorph_getShape1(morph):
    return _mingc.SWFMorph_getShape1(morph)

def SWFMorph_getShape2(morph):
    return _mingc.SWFMorph_getShape2(morph)

def newSWFFont_fromFile(filename):
    return _mingc.newSWFFont_fromFile(filename)

def destroySWFFont(font):
    return _mingc.destroySWFFont(font)

def SWFFont_getStringWidth(font, string):
    return _mingc.SWFFont_getStringWidth(font, string)

def SWFFont_getUTF8StringWidth(font, string):
    return _mingc.SWFFont_getUTF8StringWidth(font, string)

def SWFFont_getWideStringWidth(font, string, len):
    return _mingc.SWFFont_getWideStringWidth(font, string, len)

def SWFFont_getAscent(font):
    return _mingc.SWFFont_getAscent(font)

def SWFFont_getDescent(font):
    return _mingc.SWFFont_getDescent(font)

def SWFFont_getLeading(font):
    return _mingc.SWFFont_getLeading(font)

def SWFFont_getName(font):
    return _mingc.SWFFont_getName(font)

def SWFFont_getGlyphCount(font):
    return _mingc.SWFFont_getGlyphCount(font)

def newSWFFontCollection_fromFile(filename):
    return _mingc.newSWFFontCollection_fromFile(filename)

def SWFFontCollection_getFontCount(collection):
    return _mingc.SWFFontCollection_getFontCount(collection)

def SWFFontCollection_getFont(collection, index):
    return _mingc.SWFFontCollection_getFont(collection, index)

def destroySWFFontCollection(collection):
    return _mingc.destroySWFFontCollection(collection)

def newSWFText():
    return _mingc.newSWFText()

def newSWFText2():
    return _mingc.newSWFText2()

def destroySWFText(text):
    return _mingc.destroySWFText(text)

def SWFText_setFont(text, font):
    return _mingc.SWFText_setFont(text, font)

def SWFText_setHeight(text, height):
    return _mingc.SWFText_setHeight(text, height)

def SWFText_setColor(text, r, g, b, a):
    return _mingc.SWFText_setColor(text, r, g, b, a)

def SWFText_moveTo(text, x, y):
    return _mingc.SWFText_moveTo(text, x, y)

def SWFText_addString(text, string, advance):
    return _mingc.SWFText_addString(text, string, advance)

def SWFText_addUTF8String(text, string, advance):
    return _mingc.SWFText_addUTF8String(text, string, advance)

def SWFText_addWideString(text, string, strlen, advance):
    return _mingc.SWFText_addWideString(text, string, strlen, advance)

def SWFText_setSpacing(text, spacing):
    return _mingc.SWFText_setSpacing(text, spacing)

def SWFText_getStringWidth(text, string):
    return _mingc.SWFText_getStringWidth(text, string)

def SWFText_getUTF8StringWidth(text, string):
    return _mingc.SWFText_getUTF8StringWidth(text, string)

def SWFText_getWideStringWidth(text, string):
    return _mingc.SWFText_getWideStringWidth(text, string)

def SWFText_getAscent(text):
    return _mingc.SWFText_getAscent(text)

def SWFText_getDescent(text):
    return _mingc.SWFText_getDescent(text)

def SWFText_getLeading(text):
    return _mingc.SWFText_getLeading(text)

def newSWFBrowserFont(name):
    return _mingc.newSWFBrowserFont(name)

def destroySWFBrowserFont(browserFont):
    return _mingc.destroySWFBrowserFont(browserFont)

def SWFFontCharacter_addChars(font, string):
    return _mingc.SWFFontCharacter_addChars(font, string)

def SWFFontCharacter_addUTF8Chars(font, string):
    return _mingc.SWFFontCharacter_addUTF8Chars(font, string)
SWFTEXTFIELD_ONMASK = _mingc.SWFTEXTFIELD_ONMASK
SWFTEXTFIELD_OFFMASK = _mingc.SWFTEXTFIELD_OFFMASK
SWFTEXTFIELD_HASFONT = _mingc.SWFTEXTFIELD_HASFONT
SWFTEXTFIELD_HASLENGTH = _mingc.SWFTEXTFIELD_HASLENGTH
SWFTEXTFIELD_HASCOLOR = _mingc.SWFTEXTFIELD_HASCOLOR
SWFTEXTFIELD_NOEDIT = _mingc.SWFTEXTFIELD_NOEDIT
SWFTEXTFIELD_PASSWORD = _mingc.SWFTEXTFIELD_PASSWORD
SWFTEXTFIELD_MULTILINE = _mingc.SWFTEXTFIELD_MULTILINE
SWFTEXTFIELD_WORDWRAP = _mingc.SWFTEXTFIELD_WORDWRAP
SWFTEXTFIELD_HASTEXT = _mingc.SWFTEXTFIELD_HASTEXT
SWFTEXTFIELD_USEFONT = _mingc.SWFTEXTFIELD_USEFONT
SWFTEXTFIELD_HTML = _mingc.SWFTEXTFIELD_HTML
SWFTEXTFIELD_DRAWBOX = _mingc.SWFTEXTFIELD_DRAWBOX
SWFTEXTFIELD_NOSELECT = _mingc.SWFTEXTFIELD_NOSELECT
SWFTEXTFIELD_HASLAYOUT = _mingc.SWFTEXTFIELD_HASLAYOUT
SWFTEXTFIELD_AUTOSIZE = _mingc.SWFTEXTFIELD_AUTOSIZE
SWFTEXTFIELD_ALIGN_LEFT = _mingc.SWFTEXTFIELD_ALIGN_LEFT
SWFTEXTFIELD_ALIGN_RIGHT = _mingc.SWFTEXTFIELD_ALIGN_RIGHT
SWFTEXTFIELD_ALIGN_CENTER = _mingc.SWFTEXTFIELD_ALIGN_CENTER
SWFTEXTFIELD_ALIGN_JUSTIFY = _mingc.SWFTEXTFIELD_ALIGN_JUSTIFY

def newSWFTextField():
    return _mingc.newSWFTextField()

def destroySWFTextField(textField):
    return _mingc.destroySWFTextField(textField)

def SWFTextField_setFont(field, font):
    return _mingc.SWFTextField_setFont(field, font)

def SWFTextField_setBounds(field, width, height):
    return _mingc.SWFTextField_setBounds(field, width, height)

def SWFTextField_setFlags(field, flags):
    return _mingc.SWFTextField_setFlags(field, flags)

def SWFTextField_setColor(field, r, g, b, a):
    return _mingc.SWFTextField_setColor(field, r, g, b, a)

def SWFTextField_setVariableName(field, name):
    return _mingc.SWFTextField_setVariableName(field, name)

def SWFTextField_addString(field, string):
    return _mingc.SWFTextField_addString(field, string)

def SWFTextField_addUTF8String(field, string):
    return _mingc.SWFTextField_addUTF8String(field, string)

def SWFTextField_setHeight(field, height):
    return _mingc.SWFTextField_setHeight(field, height)

def SWFTextField_setFieldHeight(field, height):
    return _mingc.SWFTextField_setFieldHeight(field, height)

def SWFTextField_setLeftMargin(field, leftMargin):
    return _mingc.SWFTextField_setLeftMargin(field, leftMargin)

def SWFTextField_setRightMargin(field, rightMargin):
    return _mingc.SWFTextField_setRightMargin(field, rightMargin)

def SWFTextField_setIndentation(field, indentation):
    return _mingc.SWFTextField_setIndentation(field, indentation)

def SWFTextField_setLineSpacing(field, lineSpacing):
    return _mingc.SWFTextField_setLineSpacing(field, lineSpacing)

def SWFTextField_setPadding(field, padding):
    return _mingc.SWFTextField_setPadding(field, padding)

def SWFTextField_addChars(field, string):
    return _mingc.SWFTextField_addChars(field, string)

def SWFTextField_setAlignment(field, alignment):
    return _mingc.SWFTextField_setAlignment(field, alignment)

def SWFTextField_setLength(field, length):
    return _mingc.SWFTextField_setLength(field, length)

def newSWFSoundStream(file):
    return _mingc.newSWFSoundStream(file)

def newSWFSoundStreamFromFileno(fd):
    return _mingc.newSWFSoundStreamFromFileno(fd)

def newSWFSoundStream_fromInput(input):
    return _mingc.newSWFSoundStream_fromInput(input)

def destroySWFSoundStream(soundStream):
    return _mingc.destroySWFSoundStream(soundStream)

def SWFSoundStream_getDuration(arg1):
    return _mingc.SWFSoundStream_getDuration(arg1)

def SWFSoundStream_setInitialMp3Delay(soundStream, delay):
    return _mingc.SWFSoundStream_setInitialMp3Delay(soundStream, delay)

def newSWFSound(file, flags):
    return _mingc.newSWFSound(file, flags)

def newSWFSoundFromFileno(fd, flags):
    return _mingc.newSWFSoundFromFileno(fd, flags)

def newSWFSound_fromInput(input, flags):
    return _mingc.newSWFSound_fromInput(input, flags)

def newSWFSound_fromSoundStream(stream):
    return _mingc.newSWFSound_fromSoundStream(stream)

def destroySWFSound(sound):
    return _mingc.destroySWFSound(sound)

def SWFSound_setInitialMp3Delay(sound, delay):
    return _mingc.SWFSound_setInitialMp3Delay(sound, delay)
SWF_SOUND_COMPRESSION = _mingc.SWF_SOUND_COMPRESSION
SWF_SOUND_NOT_COMPRESSED = _mingc.SWF_SOUND_NOT_COMPRESSED
SWF_SOUND_ADPCM_COMPRESSED = _mingc.SWF_SOUND_ADPCM_COMPRESSED
SWF_SOUND_MP3_COMPRESSED = _mingc.SWF_SOUND_MP3_COMPRESSED
SWF_SOUND_NOT_COMPRESSED_LE = _mingc.SWF_SOUND_NOT_COMPRESSED_LE
SWF_SOUND_NELLY_COMPRESSED = _mingc.SWF_SOUND_NELLY_COMPRESSED
SWF_SOUND_RATE = _mingc.SWF_SOUND_RATE
SWF_SOUND_5KHZ = _mingc.SWF_SOUND_5KHZ
SWF_SOUND_11KHZ = _mingc.SWF_SOUND_11KHZ
SWF_SOUND_22KHZ = _mingc.SWF_SOUND_22KHZ
SWF_SOUND_44KHZ = _mingc.SWF_SOUND_44KHZ
SWF_SOUND_BITS = _mingc.SWF_SOUND_BITS
SWF_SOUND_8BITS = _mingc.SWF_SOUND_8BITS
SWF_SOUND_16BITS = _mingc.SWF_SOUND_16BITS
SWF_SOUND_CHANNELS = _mingc.SWF_SOUND_CHANNELS
SWF_SOUND_MONO = _mingc.SWF_SOUND_MONO
SWF_SOUND_STEREO = _mingc.SWF_SOUND_STEREO

def SWFSoundInstance_setLoopInPoint(instance, point):
    return _mingc.SWFSoundInstance_setLoopInPoint(instance, point)

def SWFSoundInstance_setLoopOutPoint(instance, point):
    return _mingc.SWFSoundInstance_setLoopOutPoint(instance, point)

def SWFSoundInstance_setLoopCount(instance, count):
    return _mingc.SWFSoundInstance_setLoopCount(instance, count)

def SWFSoundInstance_setNoMultiple(instance):
    return _mingc.SWFSoundInstance_setNoMultiple(instance)

def newSWFCXform(rAdd, gAdd, bAdd, aAdd, rMult, gMult, bMult, aMult):
    return _mingc.newSWFCXform(rAdd, gAdd, bAdd, aAdd, rMult, gMult, bMult, aMult)

def newSWFAddCXform(rAdd, gAdd, bAdd, aAdd):
    return _mingc.newSWFAddCXform(rAdd, gAdd, bAdd, aAdd)

def newSWFMultCXform(rMult, gMult, bMult, aMult):
    return _mingc.newSWFMultCXform(rMult, gMult, bMult, aMult)

def destroySWFCXform(cXform):
    return _mingc.destroySWFCXform(cXform)

def SWFCXform_setColorAdd(cXform, rAdd, gAdd, bAdd, aAdd):
    return _mingc.SWFCXform_setColorAdd(cXform, rAdd, gAdd, bAdd, aAdd)

def SWFCXform_setColorMult(cXform, rMult, gMult, bMult, aMult):
    return _mingc.SWFCXform_setColorMult(cXform, rMult, gMult, bMult, aMult)

def newSWFAction(script):
    return _mingc.newSWFAction(script)

def newSWFAction_fromFile(filename):
    return _mingc.newSWFAction_fromFile(filename)

def SWFAction_compile(action, swfVersion, length):
    return _mingc.SWFAction_compile(action, swfVersion, length)

def destroySWFAction(action):
    return _mingc.destroySWFAction(action)

def SWFAction_getByteCode(action, length):
    return _mingc.SWFAction_getByteCode(action, length)

def newSWFInitAction(action):
    return _mingc.newSWFInitAction(action)

def newSWFInitAction_withId(action, id):
    return _mingc.newSWFInitAction_withId(action, id)
SWFBUTTON_HIT = _mingc.SWFBUTTON_HIT
SWFBUTTON_DOWN = _mingc.SWFBUTTON_DOWN
SWFBUTTON_OVER = _mingc.SWFBUTTON_OVER
SWFBUTTON_UP = _mingc.SWFBUTTON_UP
SWFBUTTONRECORD_HITSTATE = _mingc.SWFBUTTONRECORD_HITSTATE
SWFBUTTONRECORD_DOWNSTATE = _mingc.SWFBUTTONRECORD_DOWNSTATE
SWFBUTTONRECORD_OVERSTATE = _mingc.SWFBUTTONRECORD_OVERSTATE
SWFBUTTONRECORD_UPSTATE = _mingc.SWFBUTTONRECORD_UPSTATE
SWFBUTTON_OVERDOWNTOIDLE = _mingc.SWFBUTTON_OVERDOWNTOIDLE
SWFBUTTON_IDLETOOVERDOWN = _mingc.SWFBUTTON_IDLETOOVERDOWN
SWFBUTTON_OUTDOWNTOIDLE = _mingc.SWFBUTTON_OUTDOWNTOIDLE
SWFBUTTON_OUTDOWNTOOVERDOWN = _mingc.SWFBUTTON_OUTDOWNTOOVERDOWN
SWFBUTTON_OVERDOWNTOOUTDOWN = _mingc.SWFBUTTON_OVERDOWNTOOUTDOWN
SWFBUTTON_OVERDOWNTOOVERUP = _mingc.SWFBUTTON_OVERDOWNTOOVERUP
SWFBUTTON_OVERUPTOOVERDOWN = _mingc.SWFBUTTON_OVERUPTOOVERDOWN
SWFBUTTON_OVERUPTOIDLE = _mingc.SWFBUTTON_OVERUPTOIDLE
SWFBUTTON_IDLETOOVERUP = _mingc.SWFBUTTON_IDLETOOVERUP
SWFBUTTON_MOUSEUPOUTSIDE = _mingc.SWFBUTTON_MOUSEUPOUTSIDE
SWFBUTTON_DRAGOVER = _mingc.SWFBUTTON_DRAGOVER
SWFBUTTON_DRAGOUT = _mingc.SWFBUTTON_DRAGOUT
SWFBUTTON_MOUSEUP = _mingc.SWFBUTTON_MOUSEUP
SWFBUTTON_MOUSEDOWN = _mingc.SWFBUTTON_MOUSEDOWN
SWFBUTTON_MOUSEOUT = _mingc.SWFBUTTON_MOUSEOUT
SWFBUTTON_MOUSEOVER = _mingc.SWFBUTTON_MOUSEOVER

def newSWFButton():
    return _mingc.newSWFButton()

def destroySWFButton(button):
    return _mingc.destroySWFButton(button)

def SWFButton_addCharacter(arg1, arg2, flags):
    return _mingc.SWFButton_addCharacter(arg1, arg2, flags)

def SWFButton_addAction(button, action, flags):
    return _mingc.SWFButton_addAction(button, action, flags)

def SWFButton_addSound(button, action, flags):
    return _mingc.SWFButton_addSound(button, action, flags)

def SWFButton_setMenu(button, flag):
    return _mingc.SWFButton_setMenu(button, flag)

def SWFButton_setScalingGrid(b, x, y, w, h):
    return _mingc.SWFButton_setScalingGrid(b, x, y, w, h)

def SWFButton_removeScalingGrid(b):
    return _mingc.SWFButton_removeScalingGrid(b)

def SWFButtonRecord_setDepth(b, depth):
    return _mingc.SWFButtonRecord_setDepth(b, depth)

def SWFButtonRecord_addFilter(b, f):
    return _mingc.SWFButtonRecord_addFilter(b, f)

def SWFButtonRecord_setBlendMode(b, mode):
    return _mingc.SWFButtonRecord_setBlendMode(b, mode)

def SWFButtonRecord_move(record, x, y):
    return _mingc.SWFButtonRecord_move(record, x, y)

def SWFButtonRecord_moveTo(record, x, y):
    return _mingc.SWFButtonRecord_moveTo(record, x, y)

def SWFButtonRecord_rotate(record, deg):
    return _mingc.SWFButtonRecord_rotate(record, deg)

def SWFButtonRecord_rotateTo(record, deg):
    return _mingc.SWFButtonRecord_rotateTo(record, deg)

def SWFButtonRecord_scale(record, scaleX, scaleY):
    return _mingc.SWFButtonRecord_scale(record, scaleX, scaleY)

def SWFButtonRecord_scaleTo(record, scaleX, scaleY):
    return _mingc.SWFButtonRecord_scaleTo(record, scaleX, scaleY)

def SWFButtonRecord_skewX(record, skewX):
    return _mingc.SWFButtonRecord_skewX(record, skewX)

def SWFButtonRecord_skewXTo(record, skewX):
    return _mingc.SWFButtonRecord_skewXTo(record, skewX)

def SWFButtonRecord_skewY(record, skewY):
    return _mingc.SWFButtonRecord_skewY(record, skewY)

def SWFButtonRecord_skewYTo(record, skewY):
    return _mingc.SWFButtonRecord_skewYTo(record, skewY)
SWFVIDEOSTREAM_MODE_AUTO = _mingc.SWFVIDEOSTREAM_MODE_AUTO
SWFVIDEOSTREAM_MODE_MANUAL = _mingc.SWFVIDEOSTREAM_MODE_MANUAL

def newSWFVideoStream_fromFile(f):
    return _mingc.newSWFVideoStream_fromFile(f)

def newSWFVideoStream_fromInput(input):
    return _mingc.newSWFVideoStream_fromInput(input)

def newSWFVideoStream():
    return _mingc.newSWFVideoStream()

def SWFVideoStream_setDimension(stream, width, height):
    return _mingc.SWFVideoStream_setDimension(stream, width, height)

def SWFVideoStream_getNumFrames(stream):
    return _mingc.SWFVideoStream_getNumFrames(stream)

def SWFVideoStream_hasAudio(stream):
    return _mingc.SWFVideoStream_hasAudio(stream)

def SWFVideoStream_setFrameMode(stream, mode):
    return _mingc.SWFVideoStream_setFrameMode(stream, mode)

def SWFVideoStream_nextFrame(stream):
    return _mingc.SWFVideoStream_nextFrame(stream)

def SWFVideoStream_seek(stream, frame, whence):
    return _mingc.SWFVideoStream_seek(stream, frame, whence)

def destroySWFVideoStream(stream):
    return _mingc.destroySWFVideoStream(stream)

def newSWFSprite():
    return _mingc.newSWFSprite()

def destroySWFSprite(sprite):
    return _mingc.destroySWFSprite(sprite)

def SWFSprite_addBlock(sprite, block):
    return _mingc.SWFSprite_addBlock(sprite, block)

def newSWFPosition(matrix):
    return _mingc.newSWFPosition(matrix)

def destroySWFPosition(position):
    return _mingc.destroySWFPosition(position)

def SWFPosition_skewX(position, x):
    return _mingc.SWFPosition_skewX(position, x)

def SWFPosition_skewXTo(position, x):
    return _mingc.SWFPosition_skewXTo(position, x)

def SWFPosition_skewY(position, y):
    return _mingc.SWFPosition_skewY(position, y)

def SWFPosition_skewYTo(position, y):
    return _mingc.SWFPosition_skewYTo(position, y)

def SWFPosition_scaleX(position, x):
    return _mingc.SWFPosition_scaleX(position, x)

def SWFPosition_scaleXTo(position, x):
    return _mingc.SWFPosition_scaleXTo(position, x)

def SWFPosition_scaleY(position, y):
    return _mingc.SWFPosition_scaleY(position, y)

def SWFPosition_scaleYTo(position, y):
    return _mingc.SWFPosition_scaleYTo(position, y)

def SWFPosition_scaleXY(position, x, y):
    return _mingc.SWFPosition_scaleXY(position, x, y)

def SWFPosition_scaleXYTo(position, x, y):
    return _mingc.SWFPosition_scaleXYTo(position, x, y)

def SWFPosition_getMatrix(p):
    return _mingc.SWFPosition_getMatrix(p)

def SWFPosition_setMatrix(p, a, b, c, d, x, y):
    return _mingc.SWFPosition_setMatrix(p, a, b, c, d, x, y)

def SWFPosition_rotate(position, degrees):
    return _mingc.SWFPosition_rotate(position, degrees)

def SWFPosition_rotateTo(position, degrees):
    return _mingc.SWFPosition_rotateTo(position, degrees)

def SWFPosition_move(position, x, y):
    return _mingc.SWFPosition_move(position, x, y)

def SWFPosition_moveTo(position, x, y):
    return _mingc.SWFPosition_moveTo(position, x, y)

def SWFPosition_getRotation(position):
    return _mingc.SWFPosition_getRotation(position)

def SWFPosition_getX(position):
    return _mingc.SWFPosition_getX(position)

def SWFPosition_getY(position):
    return _mingc.SWFPosition_getY(position)

def SWFPosition_getXY(position, outX, outY):
    return _mingc.SWFPosition_getXY(position, outX, outY)

def SWFPosition_getXScale(position):
    return _mingc.SWFPosition_getXScale(position)

def SWFPosition_getYScale(position):
    return _mingc.SWFPosition_getYScale(position)

def SWFPosition_getXYScale(position, outXScale, outYScale):
    return _mingc.SWFPosition_getXYScale(position, outXScale, outYScale)

def SWFPosition_getXSkew(position):
    return _mingc.SWFPosition_getXSkew(position)

def SWFPosition_getYSkew(position):
    return _mingc.SWFPosition_getYSkew(position)

def SWFPosition_getXYSkew(position, outXSkew, outYSkew):
    return _mingc.SWFPosition_getXYSkew(position, outXSkew, outYSkew)

def SWFDisplayItem_getCharacter(item):
    return _mingc.SWFDisplayItem_getCharacter(item)

def SWFDisplayItem_endMask(item):
    return _mingc.SWFDisplayItem_endMask(item)

def SWFDisplayItem_move(item, x, y):
    return _mingc.SWFDisplayItem_move(item, x, y)

def SWFDisplayItem_moveTo(item, x, y):
    return _mingc.SWFDisplayItem_moveTo(item, x, y)

def SWFDisplayItem_rotate(item, degrees):
    return _mingc.SWFDisplayItem_rotate(item, degrees)

def SWFDisplayItem_rotateTo(item, degrees):
    return _mingc.SWFDisplayItem_rotateTo(item, degrees)

def SWFDisplayItem_scale(item, xScale, yScale):
    return _mingc.SWFDisplayItem_scale(item, xScale, yScale)

def SWFDisplayItem_scaleTo(item, xScale, yScale):
    return _mingc.SWFDisplayItem_scaleTo(item, xScale, yScale)

def SWFDisplayItem_skewX(item, x):
    return _mingc.SWFDisplayItem_skewX(item, x)

def SWFDisplayItem_skewXTo(item, x):
    return _mingc.SWFDisplayItem_skewXTo(item, x)

def SWFDisplayItem_skewY(item, y):
    return _mingc.SWFDisplayItem_skewY(item, y)

def SWFDisplayItem_skewYTo(item, y):
    return _mingc.SWFDisplayItem_skewYTo(item, y)

def SWFDisplayItem_getPosition(item, x, y):
    return _mingc.SWFDisplayItem_getPosition(item, x, y)

def SWFDisplayItem_getRotation(item, degrees):
    return _mingc.SWFDisplayItem_getRotation(item, degrees)

def SWFDisplayItem_getScale(item, xScale, yScale):
    return _mingc.SWFDisplayItem_getScale(item, xScale, yScale)

def SWFDisplayItem_getSkew(item, xSkew, ySkew):
    return _mingc.SWFDisplayItem_getSkew(item, xSkew, ySkew)

def SWFDisplayItem_getMatrix(item):
    return _mingc.SWFDisplayItem_getMatrix(item)

def SWFDisplayItem_setMatrix(i, a, b, c, d, x, y):
    return _mingc.SWFDisplayItem_setMatrix(i, a, b, c, d, x, y)

def SWFDisplayItem_getDepth(item):
    return _mingc.SWFDisplayItem_getDepth(item)

def SWFDisplayItem_setDepth(item, depth):
    return _mingc.SWFDisplayItem_setDepth(item, depth)

def SWFDisplayItem_remove(item):
    return _mingc.SWFDisplayItem_remove(item)

def SWFDisplayItem_setName(item, name):
    return _mingc.SWFDisplayItem_setName(item, name)

def SWFDisplayItem_setMaskLevel(item, masklevel):
    return _mingc.SWFDisplayItem_setMaskLevel(item, masklevel)

def SWFDisplayItem_setRatio(item, ratio):
    return _mingc.SWFDisplayItem_setRatio(item, ratio)

def SWFDisplayItem_setCXform(item, cXform):
    return _mingc.SWFDisplayItem_setCXform(item, cXform)

def SWFDisplayItem_setColorAdd(item, r, g, b, a):
    return _mingc.SWFDisplayItem_setColorAdd(item, r, g, b, a)

def SWFDisplayItem_setColorMult(item, r, g, b, a):
    return _mingc.SWFDisplayItem_setColorMult(item, r, g, b, a)
SWFACTION_ONLOAD = _mingc.SWFACTION_ONLOAD
SWFACTION_ENTERFRAME = _mingc.SWFACTION_ENTERFRAME
SWFACTION_UNLOAD = _mingc.SWFACTION_UNLOAD
SWFACTION_MOUSEMOVE = _mingc.SWFACTION_MOUSEMOVE
SWFACTION_MOUSEDOWN = _mingc.SWFACTION_MOUSEDOWN
SWFACTION_MOUSEUP = _mingc.SWFACTION_MOUSEUP
SWFACTION_KEYDOWN = _mingc.SWFACTION_KEYDOWN
SWFACTION_KEYUP = _mingc.SWFACTION_KEYUP
SWFACTION_DATA = _mingc.SWFACTION_DATA

def SWFDisplayItem_addAction(item, action, flags):
    return _mingc.SWFDisplayItem_addAction(item, action, flags)

def SWFDisplayItem_cacheAsBitmap(item, flag):
    return _mingc.SWFDisplayItem_cacheAsBitmap(item, flag)
SWFBLEND_MODE_NULL = _mingc.SWFBLEND_MODE_NULL
SWFBLEND_MODE_NORMAL = _mingc.SWFBLEND_MODE_NORMAL
SWFBLEND_MODE_LAYER = _mingc.SWFBLEND_MODE_LAYER
SWFBLEND_MODE_MULT = _mingc.SWFBLEND_MODE_MULT
SWFBLEND_MODE_SCREEN = _mingc.SWFBLEND_MODE_SCREEN
SWFBLEND_MODE_LIGHTEN = _mingc.SWFBLEND_MODE_LIGHTEN
SWFBLEND_MODE_DARKEN = _mingc.SWFBLEND_MODE_DARKEN
SWFBLEND_MODE_DIFF = _mingc.SWFBLEND_MODE_DIFF
SWFBLEND_MODE_ADD = _mingc.SWFBLEND_MODE_ADD
SWFBLEND_MODE_SUB = _mingc.SWFBLEND_MODE_SUB
SWFBLEND_MODE_INV = _mingc.SWFBLEND_MODE_INV
SWFBLEND_MODE_ALPHA = _mingc.SWFBLEND_MODE_ALPHA
SWFBLEND_MODE_ERASE = _mingc.SWFBLEND_MODE_ERASE
SWFBLEND_MODE_OVERLAY = _mingc.SWFBLEND_MODE_OVERLAY
SWFBLEND_MODE_HARDLIGHT = _mingc.SWFBLEND_MODE_HARDLIGHT

def SWFDisplayItem_setBlendMode(item, mode):
    return _mingc.SWFDisplayItem_setBlendMode(item, mode)

def newSWFFill(fillstyle):
    return _mingc.newSWFFill(fillstyle)

def destroySWFFill(fill):
    return _mingc.destroySWFFill(fill)

def SWFFill_getFillStyle(fill):
    return _mingc.SWFFill_getFillStyle(fill)

def SWFFill_skewX(fill, x):
    return _mingc.SWFFill_skewX(fill, x)

def SWFFill_skewXTo(fill, x):
    return _mingc.SWFFill_skewXTo(fill, x)

def SWFFill_skewY(fill, y):
    return _mingc.SWFFill_skewY(fill, y)

def SWFFill_skewYTo(fill, y):
    return _mingc.SWFFill_skewYTo(fill, y)

def SWFFill_scaleX(fill, x):
    return _mingc.SWFFill_scaleX(fill, x)

def SWFFill_scaleXTo(fill, x):
    return _mingc.SWFFill_scaleXTo(fill, x)

def SWFFill_scaleY(fill, y):
    return _mingc.SWFFill_scaleY(fill, y)

def SWFFill_scaleYTo(fill, y):
    return _mingc.SWFFill_scaleYTo(fill, y)

def SWFFill_scaleXY(fill, x, y):
    return _mingc.SWFFill_scaleXY(fill, x, y)

def SWFFill_scaleXYTo(fill, x, y):
    return _mingc.SWFFill_scaleXYTo(fill, x, y)

def SWFFill_rotate(fill, degrees):
    return _mingc.SWFFill_rotate(fill, degrees)

def SWFFill_rotateTo(fill, degrees):
    return _mingc.SWFFill_rotateTo(fill, degrees)

def SWFFill_move(fill, x, y):
    return _mingc.SWFFill_move(fill, x, y)

def SWFFill_moveTo(fill, x, y):
    return _mingc.SWFFill_moveTo(fill, x, y)

def SWFFill_setMatrix(fill, a, b, c, d, x, y):
    return _mingc.SWFFill_setMatrix(fill, a, b, c, d, x, y)

def SWFShape_setLine(shape, width, r, g, b, a):
    return _mingc.SWFShape_setLine(shape, width, r, g, b, a)

def SWFShape_setLine2Filled(shape, width, fill, flags, miterLimit):
    return _mingc.SWFShape_setLine2Filled(shape, width, fill, flags, miterLimit)

def SWFShape_setLine2(shape, width, r, g, b, a, flags, miterLimit):
    return _mingc.SWFShape_setLine2(shape, width, r, g, b, a, flags, miterLimit)

def SWFShape_addSolidFill(shape, r, g, b, a):
    return _mingc.SWFShape_addSolidFill(shape, r, g, b, a)

def SWFShape_addGradientFill(shape, gradient, flags):
    return _mingc.SWFShape_addGradientFill(shape, gradient, flags)

def SWFShape_addBitmapFill(shape, bitmap, flags):
    return _mingc.SWFShape_addBitmapFill(shape, bitmap, flags)

def SWFShape_setLeftFill(shape, fill):
    return _mingc.SWFShape_setLeftFill(shape, fill)

def SWFShape_setRightFill(shape, fill):
    return _mingc.SWFShape_setRightFill(shape, fill)

def SWFShape_drawArc(shape, r, startAngle, endAngle):
    return _mingc.SWFShape_drawArc(shape, r, startAngle, endAngle)

def SWFShape_drawCircle(shape, r):
    return _mingc.SWFShape_drawCircle(shape, r)

def SWFShape_drawGlyph(shape, font, c):
    return _mingc.SWFShape_drawGlyph(shape, font, c)

def SWFShape_drawSizedGlyph(shape, font, c, size):
    return _mingc.SWFShape_drawSizedGlyph(shape, font, c, size)

def SWFShape_drawCubic(shape, bx, by, cx, cy, dx, dy):
    return _mingc.SWFShape_drawCubic(shape, bx, by, cx, cy, dx, dy)

def SWFShape_drawCubicTo(shape, bx, by, cx, cy, dx, dy):
    return _mingc.SWFShape_drawCubicTo(shape, bx, by, cx, cy, dx, dy)

def SWFShape_drawCharacterBounds(shape, character):
    return _mingc.SWFShape_drawCharacterBounds(shape, character)

def newSWFMovieClip():
    return _mingc.newSWFMovieClip()

def destroySWFMovieClip(movieClip):
    return _mingc.destroySWFMovieClip(movieClip)

def SWFMovieClip_setNumberOfFrames(clip, frames):
    return _mingc.SWFMovieClip_setNumberOfFrames(clip, frames)

def SWFMovieClip_nextFrame(clip):
    return _mingc.SWFMovieClip_nextFrame(clip)

def SWFMovieClip_labelFrame(clip, label):
    return _mingc.SWFMovieClip_labelFrame(clip, label)

def SWFMovieClip_add(clip, block):
    return _mingc.SWFMovieClip_add(clip, block)

def SWFMovieClip_remove(clip, item):
    return _mingc.SWFMovieClip_remove(clip, item)

def SWFMovieClip_setSoundStreamAt(clip, sound, rate, skipSound):
    return _mingc.SWFMovieClip_setSoundStreamAt(clip, sound, rate, skipSound)

def SWFMovieClip_setSoundStream(clip, sound, rate):
    return _mingc.SWFMovieClip_setSoundStream(clip, sound, rate)

def SWFMovieClip_startSound(clip, sound):
    return _mingc.SWFMovieClip_startSound(clip, sound)

def SWFMovieClip_stopSound(clip, sound):
    return _mingc.SWFMovieClip_stopSound(clip, sound)

def destroySWFPrebuiltClip(clip):
    return _mingc.destroySWFPrebuiltClip(clip)

def newSWFPrebuiltClip_fromFile(filename):
    return _mingc.newSWFPrebuiltClip_fromFile(filename)

def newSWFPrebuiltClip_fromInput(input):
    return _mingc.newSWFPrebuiltClip_fromInput(input)

def newSWFBinaryData(blob, length):
    return _mingc.newSWFBinaryData(blob, length)

def newSWFMovie():
    return _mingc.newSWFMovie()

def newSWFMovieWithVersion(version):
    return _mingc.newSWFMovieWithVersion(version)

def destroySWFMovie(movie):
    return _mingc.destroySWFMovie(movie)

def SWFMovie_setRate(movie, rate):
    return _mingc.SWFMovie_setRate(movie, rate)

def SWFMovie_getRate(movie):
    return _mingc.SWFMovie_getRate(movie)

def SWFMovie_setDimension(movie, x, y):
    return _mingc.SWFMovie_setDimension(movie, x, y)

def SWFMovie_setNumberOfFrames(movie, frames):
    return _mingc.SWFMovie_setNumberOfFrames(movie, frames)

def SWFMovie_addExport(movie, block, name):
    return _mingc.SWFMovie_addExport(movie, block, name)

def SWFMovie_setBackground(movie, r, g, b):
    return _mingc.SWFMovie_setBackground(movie, r, g, b)

def SWFMovie_setSoundStream(movie, sound):
    return _mingc.SWFMovie_setSoundStream(movie, sound)

def SWFMovie_setSoundStreamAt(movie, stream, skip):
    return _mingc.SWFMovie_setSoundStreamAt(movie, stream, skip)

def SWFMovie_startSound(movie, sound):
    return _mingc.SWFMovie_startSound(movie, sound)

def SWFMovie_stopSound(movie, sound):
    return _mingc.SWFMovie_stopSound(movie, sound)

def SWFMovie_add(movie, block):
    return _mingc.SWFMovie_add(movie, block)

def SWFMovie_remove(movie, item):
    return _mingc.SWFMovie_remove(movie, item)

def SWFMovie_nextFrame(movie):
    return _mingc.SWFMovie_nextFrame(movie)

def SWFMovie_labelFrame(movie, label):
    return _mingc.SWFMovie_labelFrame(movie, label)

def SWFMovie_output(movie, method, data):
    return _mingc.SWFMovie_output(movie, method, data)

def SWFMovie_save(movie, filename):
    return _mingc.SWFMovie_save(movie, filename)

def SWFMovie_protect(movie, password):
    return _mingc.SWFMovie_protect(movie, password)

def SWFMovie_setNetworkAccess(movie, flag):
    return _mingc.SWFMovie_setNetworkAccess(movie, flag)

def SWFMovie_addMetadata(movie, xml):
    return _mingc.SWFMovie_addMetadata(movie, xml)

def SWFMovie_setScriptLimits(movie, maxRecursion, timeout):
    return _mingc.SWFMovie_setScriptLimits(movie, maxRecursion, timeout)

def SWFMovie_setTabIndex(movie, depth, i):
    return _mingc.SWFMovie_setTabIndex(movie, depth, i)

def SWFMovie_importFont(movie, filename, name):
    return _mingc.SWFMovie_importFont(movie, filename, name)

def SWFMovie_addFont(movie, font):
    return _mingc.SWFMovie_addFont(movie, font)

def SWFMovie_importCharacter(movie, filename, name):
    return _mingc.SWFMovie_importCharacter(movie, filename, name)

def SWFMovie_assignSymbol(m, character, name):
    return _mingc.SWFMovie_assignSymbol(m, character, name)

def SWFMovie_defineScene(m, offset, name):
    return _mingc.SWFMovie_defineScene(m, offset, name)

def SWFMovie_namedAnchor(movie, label):
    return _mingc.SWFMovie_namedAnchor(movie, label)

def SWFMovie_writeExports(movie):
    return _mingc.SWFMovie_writeExports(movie)
SWFFILTER_MODE_INNER = _mingc.SWFFILTER_MODE_INNER
SWFFILTER_MODE_KO = _mingc.SWFFILTER_MODE_KO
SWFFILTER_MODE_COMPOSITE = _mingc.SWFFILTER_MODE_COMPOSITE
SWFFILTER_MODE_ONTOP = _mingc.SWFFILTER_MODE_ONTOP
SWFFILTER_FLAG_CLAMP = _mingc.SWFFILTER_FLAG_CLAMP
SWFFILTER_FLAG_PRESERVE_ALPHA = _mingc.SWFFILTER_FLAG_PRESERVE_ALPHA
SWFFILTER_TYPE_DROPSHADOW = _mingc.SWFFILTER_TYPE_DROPSHADOW
SWFFILTER_TYPE_BLUR = _mingc.SWFFILTER_TYPE_BLUR
SWFFILTER_TYPE_GLOW = _mingc.SWFFILTER_TYPE_GLOW
SWFFILTER_TYPE_BEVEL = _mingc.SWFFILTER_TYPE_BEVEL
SWFFILTER_TYPE_GRADIENTGLOW = _mingc.SWFFILTER_TYPE_GRADIENTGLOW
SWFFILTER_TYPE_CONVOLUTION = _mingc.SWFFILTER_TYPE_CONVOLUTION
SWFFILTER_TYPE_COLORMATRIX = _mingc.SWFFILTER_TYPE_COLORMATRIX
SWFFILTER_TYPE_GRADIENTBEVEL = _mingc.SWFFILTER_TYPE_GRADIENTBEVEL
class SWFColor(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    red = property(_mingc.SWFColor_red_get, _mingc.SWFColor_red_set)
    green = property(_mingc.SWFColor_green_get, _mingc.SWFColor_green_set)
    blue = property(_mingc.SWFColor_blue_get, _mingc.SWFColor_blue_set)
    alpha = property(_mingc.SWFColor_alpha_get, _mingc.SWFColor_alpha_set)

    def __init__(self):
        _mingc.SWFColor_swiginit(self, _mingc.new_SWFColor())
    __swig_destroy__ = _mingc.delete_SWFColor

# Register SWFColor in _mingc:
_mingc.SWFColor_swigregister(SWFColor)

def newSWFShadow(angle, distance, strength):
    return _mingc.newSWFShadow(angle, distance, strength)

def destroySWFShadow(s):
    return _mingc.destroySWFShadow(s)

def newSWFBlur(blurX, blurY, passes):
    return _mingc.newSWFBlur(blurX, blurY, passes)

def destroySWFBlur(b):
    return _mingc.destroySWFBlur(b)

def newSWFFilterMatrix(cols, rows, vals):
    return _mingc.newSWFFilterMatrix(cols, rows, vals)

def destroySWFFilterMatrix(m):
    return _mingc.destroySWFFilterMatrix(m)

def destroySWFFilter(filter):
    return _mingc.destroySWFFilter(filter)

def newColorMatrixFilter(matrix):
    return _mingc.newColorMatrixFilter(matrix)

def newConvolutionFilter(matrix, divisor, bias, color, flags):
    return _mingc.newConvolutionFilter(matrix, divisor, bias, color, flags)

def newGradientBevelFilter(gradient, blur, shadow, flags):
    return _mingc.newGradientBevelFilter(gradient, blur, shadow, flags)

def newGradientGlowFilter(gradient, blur, shadow, flags):
    return _mingc.newGradientGlowFilter(gradient, blur, shadow, flags)

def newBevelFilter(shadowColor, highlightColor, blur, shadow, flags):
    return _mingc.newBevelFilter(shadowColor, highlightColor, blur, shadow, flags)

def newGlowFilter(color, blur, strength, flags):
    return _mingc.newGlowFilter(color, blur, strength, flags)

def newBlurFilter(blur):
    return _mingc.newBlurFilter(blur)

def newDropShadowFilter(color, blur, shadow, flags):
    return _mingc.newDropShadowFilter(color, blur, shadow, flags)

def SWFDisplayItem_addFilter(item, filter):
    return _mingc.SWFDisplayItem_addFilter(item, filter)

